/**
 * Game of Life
 * 
 */
package gridlife.color;


/**
 * Imports
 * 
 */
import gridlife.core.GridLifeConstants;
import java.awt.Graphics           ;
import java.awt.Color              ;
import java.awt.image.BufferedImage;

import java.util.StringTokenizer;
import javax.swing.ImageIcon    ;



/**
 * Color/age record
 * 
 * @author Ulf Wagemann
 */
public class GridLifeColorRecord
{
 private int    m_iAge    ;
 private int    m_iBgColor;
 private Color  m_tBgColor;
 
 private ImageIcon m_tImage;
 
 
 
 
 /**
  * Constructor. String format: 
  * 
  * @param pa_sRecord   Comma separated age and color values as hexstrings like 00ff00. Example: 5,ff0000,ffffff
  *                     Token 1: Age
  *                     Token 2: Background color
  *                     Token 3: Foreground color
  */
 public GridLifeColorRecord(String pa_sRecord)
 {
  String lc_sToken  = "";
  StringTokenizer lc_tTokenizer = null;
  
  setDefaults();
      
  if (null != pa_sRecord)
  {
   if (null != (lc_tTokenizer =  new StringTokenizer(pa_sRecord, GridLifeConstants.GOL_FILE_COLOR_VALUE_SEPARATOR)))
   {
    try
    {
     lc_sToken = lc_tTokenizer.nextToken();
     if (null != lc_sToken) {m_iAge = (Integer.valueOf(lc_sToken.trim())).intValue();}
    
     lc_sToken = lc_tTokenizer.nextToken();
     if (null != lc_sToken) {m_iBgColor = (Integer.valueOf(lc_sToken.trim(), 16)).intValue();}

     m_tBgColor = new Color(m_iBgColor);
     m_tImage   = null;
     
     createImage();
    }
    catch (Exception e)
    {
     setDefaults();
    }
   }
  }
 }
 
 
 /**
  * Creates an image icon using the given colors
  * 
  */
 private void createImage()
 {
  Graphics      lc_tGraphics = null;
  BufferedImage lc_tImage    = null;
  
  if (null != (lc_tImage = new BufferedImage(GridLifeConstants.GOL_COLOR_RENDERER_WIDTH, GridLifeConstants.GOL_COLOR_RENDERER_HEIGHT, BufferedImage.TYPE_INT_RGB)))
  {
   if (null != (lc_tGraphics = lc_tImage.getGraphics()))
   {
    //
    // draw background
    //
    lc_tGraphics.setColor(Color.black);
    lc_tGraphics.drawRect(0, 0, GridLifeConstants.GOL_COLOR_RENDERER_WIDTH, GridLifeConstants.GOL_COLOR_RENDERER_HEIGHT);

    lc_tGraphics.setColor(m_tBgColor);
    lc_tGraphics.fillRect(1, 1, GridLifeConstants.GOL_COLOR_RENDERER_WIDTH-2, GridLifeConstants.GOL_COLOR_RENDERER_HEIGHT-2);
    
     m_tImage = new ImageIcon(lc_tImage);
   }
  }
 }
 
 
 
 /**
  * Returns the image icon
  * 
  * @return  ImageIcon
  */
 public final ImageIcon getImage() {return m_tImage;}
 
 
 
 /**
  * Sets the age
  * 
  * @param pa_iValue   Age 
  */
 public final void setAge(int pa_iValue)
 {
  if (0 <= pa_iValue && Integer.MAX_VALUE > pa_iValue) 
  {
   m_iAge = pa_iValue; 
  }
 }
 
 
 
 /**
  * Sets the background color value
  * 
  * @param pa_iValue    color value, e.g. 0xff0000
  */
 public final void setBgColorValue(int pa_iValue)
 {
  if (0 <= pa_iValue && Integer.MAX_VALUE > pa_iValue) 
  {
   m_iBgColor = pa_iValue; 
   m_tBgColor = new Color(m_iBgColor);
  }
 }
 

 
 /**
  * Sets the color
  * 
  * @param pa_tColor    Color
  */
 public final void setBgColor(Color pa_tColor)
 {
  if (null != pa_tColor) 
  {
   m_tBgColor = pa_tColor;
   m_iBgColor = m_tBgColor.hashCode();
  }
 }
 
 
 
 /**
  * Returns the age
  * 
  * @return   Age
  */
 public final int getAge() {return m_iAge;}
 
 
 
 /**
  * Returns the color value
  * 
  * @return   Color value
  */
 public final int getBgColorValue() {return m_iBgColor;}
 
 

 /**
  * Returns the color
  * 
  * @return    Color
  */
 public final Color getBgColor() {return m_tBgColor;}
 
 
 
 /**
  * Resets to defaults values
  * 
  */
 private void setDefaults()
 {
  m_iAge     = 1;
  m_iBgColor = GridLifeConstants.GOL_CELL_FILL_COLOR;
  m_tBgColor = new Color(m_iBgColor);    
  m_tImage   = null;
 }
 
}
