/**
 * Game of Life
 * 
 */
package gridlife.core;

/**
 * Global constants
 * 
 * @author Ulf Wagemann
 */
public class GridLifeConstants 
{
 //
 // quicksave filename constants
 //
 public final static char GOL_QUICKSAVE_UNDERSCORE = '_';
 public final static char GOL_QUICKSAVE_HYPHEN     = '-';
 
 //
 // Cell neighbourhood constsnts
 //
 public final static int GOL_NEIGHBOURHOOD_MOORE            = 0; // 8 cells
 public final static int GOL_NEIGHBOURHOOD_VON_NEUMANN      = 1; // 4 cells
 
 //
 // Paint type constants
 //
 public final static int GOL_PAINT_TYPE_SET = 0;
 public final static int GOL_PAINT_TYPE_XOR = 1;
 
 //
 // Topology constsnts
 //
 public final static int GOL_TOPOLOGY_SHEET = 0;
 public final static int GOL_TOPOLOGY_TORUS = 1;
 
 //
 // Helpline constsnts
 //
 public final static int GOL_HELPLINES_NONE = 0;
 public final static int GOL_HELPLINES_HALF = 1;
 public final static int GOL_HELPLINES_FULL = 2;
 

 //
 // Cell matrix constants
 //
 public final static int GOL_MIN_COLUMNS = 20 ;
 public final static int GOL_MIN_ROWS    = 20 ;
 public final static int GOL_MAX_COLUMNS = 5000;
 public final static int GOL_MAX_ROWS    = 5000;
 
 //
 // Shape constants
 //
 public final static int GOL_SHAPE_BLOCK_WIDTH  = 6;
 public final static int GOL_SHAPE_BLOCK_HEIGHT = 6;
 
 //
 // Shape default colors
 //
 public final static int GOL_SHAPE_BACKGROUND_COLOR = 0xffffff;
 public final static int GOL_SHAPE_BORDER_COLOR     = 0x000000;
 public final static int GOL_SHAPE_HILITE_COLOR     = 0xdddddd;
 public final static int GOL_SHAPE_FILL_COLOR       = 0xcccccc;
 public final static int GOL_SHAPE_SHADOW1_COLOR    = 0xcccccc;
 
 //
 // Matrix file constants
 //
 public final static String GOL_FILE_CELL_MATRIX_HEADER          = "@GOL_CELL_MATRIX@";
 public final static String GOL_FILE_CELL_MATRIX_SHAPE_HEADER    = "@"   ;
 public final static String GOL_FILE_CELL_MATRIX_COMMENT         = "#"   ;
 public final static String GOL_FILE_CELL_MATRIX_VALUE_SEPARATOR = ","   ;
 public final static String GOL_FILE_CELL_MATRIX_EXTENSION       = ".mtx";
 public final static String GOL_FILE_CELL_MATRIX_DEAD_CELL_1      = ".";
 public final static String GOL_FILE_CELL_MATRIX_DEAD_CELL_2      = "0";
 public final static String GOL_FILE_CELL_MATRIX_LIVING_CELL_1    = "O";
 public final static String GOL_FILE_CELL_MATRIX_LIVING_CELL_2    = "1";
 
 //
 // Color file constants
 //
 public final static String GOL_FILE_COLOR_HEADER          = "@GOL_COLORSET@";
 public final static String GOL_FILE_COLOR_COMMENT         = "#";
 public final static String GOL_FILE_COLOR_VALUE_SEPARATOR = ",";
 public final static String GOL_FILE_COLOR_DIR             = "colors";
 public final static String GOL_FILE_COLOR_EXTENSION       = ".gcf";

 //
 // Shape file constants
 //
 public final static String GOL_FILE_SHAPE_HEADER          = "@GOL_SHAPESET@";
 public final static String GOL_FILE_SHAPE_NAME_HEADER     = "@";
 public final static String GOL_FILE_SHAPE_COMMENT         = "#";
 public final static String GOL_FILE_SHAPE_VALUE_SEPARATOR = ",";
 
 //
 // Settings constants
 //
 public final static String GOL_SETTING_LOAD_PATH_PROPERTIES    = "LoadPropertiesPath"  ;
 public final static String GOL_SETTING_SAVE_PATH_PROPERTIES    = "SavePropertiesPath"  ;
 public final static String GOL_SETTING_LOAD_PATH_CELL_FILE     = "LoadCellFilePath"    ;
 public final static String GOL_SETTING_SAVE_PATH_CELL_FILE     = "SaveCellFilePath"    ;
 public final static String GOL_SETTING_LOAD_PATH_PALETTE_FILE  = "LoadPaletteFilePath" ;
 public final static String GOL_SETTING_SAVE_PATH_PALETTE_FILE  = "SavePaletteFilePath" ;
 public final static String GOL_SETTING_COLORSET_PATH           = "ColorPath"           ;
 public final static String GOL_SETTING_LOOK_AND_FEEL           = "LookAndFeel"         ;
 public final static String GOL_SETTING_COLORSET_PALETTE        = "ColorPalette"        ;
 public final static String GOL_SETTING_COLORSET_PALETTE_ENTRY  = "ColorPaletteEntry"   ;
 public final static String GOL_SETTING_SHAPE_PALETTE           = "ShapePalette"        ;
 public final static String GOL_SETTING_SHAPE_PALETTE_ENTRY     = "ShapePaletteEntry"   ;
 public final static String GOL_SETTING_PAINT_TYPE              = "PaintType"           ;
 public final static String GOL_SETTING_PAINT_MODE              = "PaintMode"           ;
 public final static String GOL_SETTING_ZOOM                    = "Zoom"                ;
 public final static String GOL_SETTING_FILL                    = "Fill"                ;
 public final static String GOL_SETTING_QUICK_SAVE_SLOT         = "QuickSave"           ;

 
 
 //
 // Window properties constants
 //
 public final static String GOL_WINDOW_OPEN = ".Open";
 public final static String GOL_WINDOW_X    = ".X"   ;
 public final static String GOL_WINDOW_Y    = ".Y"   ;
 public final static String GOL_WINDOW_W    = ".W"   ;
 public final static String GOL_WINDOW_H    = ".H"   ;
 
 public final static String GOL_WINDOW_CELL_MATRIX    = "WindowCellMatrix"   ;
 public final static String GOL_WINDOW_PROPERTIES     = "WindowProperties"   ;
 public final static String GOL_WINDOW_STATISTICS     = "WindowStatistics"   ;
 public final static String GOL_WINDOW_SHAPE_PALETTE  = "WindowShapePalette" ;
 public final static String GOL_WINDOW_COLOR          = "WindowColor"        ;
 public final static String GOL_WINDOW_PALETTE_EDITOR = "WindowPaletteEditor";
 
 public final static String GOL_FILE_WINDOW_SETTINGS            = "GridLifeSettings.properties";
 
 //
 // Properties file constants
 //
 public final static String GOL_FILE_PROPERTIES_HEADER          = "@GOL_PROPERTIES@";
 public final static String GOL_FILE_PROPERTIES_VALUE_SEPARATOR = ",";
 public final static String GOL_FILE_PROPERTIES_NAME            = "GridLifeProperties.prs";
 public final static String GOL_FILE_LOCALIZED_MESSAGES         = "gridlife/ui/resources/GridLifeMessages";
 
 //
 // screenshot constants
 //
 public final static String GOL_FILE_SCREENSHOT_DIR       = "screenshots";
 public final static String GOL_FILE_SCREENSHOT_EXTENSION = ".png"       ;

 
 //
 // quicksave and quickload constants
 //
 public final static String GOL_FILE_QUICKSAVE_HEADER    = "@GOL_QUICKSAVE@";
 public final static String GOL_FILE_QUICKSAVE_SEPARATOR = ","              ;
 public final static String GOL_FILE_QUICKSAVE_DIR       = "quicksave"      ;
 public final static String GOL_FILE_QUICKSAVE_EXTENSION = ".qsv"           ;
 public final static String GOL_FILE_QUICKSAVE_COMMENT   = "#"             ;

  
 //
 // Palette constants
 //
 public final static String GOL_FILE_PALETTE_DIR       = "palettes";
 public final static String GOL_FILE_PALETTE_EXTENSION = ".pal"    ;
 
 //
 // Cell drawing constants
 //
 public final static int GOL_CELL_MIN_SIZE         = 2  ;
 public final static int GOL_CELL_MAX_SIZE         = 100;
 public final static int GOL_CELL_MIN_SIZE_HILIGHT = 5  ;
 public final static int GOL_RADAR_CELL_MIN_SIZE   = 2  ;
 public final static int GOL_RADAR_CELL_MAX_SIZE   = 6  ;
 
 //
 // Cell and cell manipulation default colors
 //
 public final static int GOL_CELL_GRID_COLOR            = 0xeeeeee;
 public final static int GOL_CELL_STATISTICS_COLOR      = 0xcccccc;
 public final static int GOL_CELL_GRID_HELPLINE_COLOR   = 0xaaaaaa;
 public final static int GOL_CELL_BACKGROUND_COLOR      = 0xffffff;
 public final static int GOL_CELL_BORDER_COLOR          = 0x000000;
 public final static int GOL_CELL_FILL_COLOR            = 0xaaaaaa;   
 public final static int GOL_CELL_HILITE_COLOR          = 0xdddddd;

 public final static int   GOL_CELL_MATRIX_INSERTION_AREA_COLOR   = 0x0000aa;
 public final static int   GOL_CELL_MATRIX_INSERTION_FRAME_COLOR  = 0x0000ee;
 public final static int   GOL_CELL_MATRIX_SELECTION_BORDER_COLOR = 0x0000ff;
 public final static int   GOL_CELL_MATRIX_SELECTION_FILL_COLOR   = 0x0000bb;
 public final static float GOL_CELL_MATRIX_SELECTION_ALPHA        = 0.15f;
 
 //
 // Color window cell renderer constants
 //
 public final static int GOL_COLOR_RENDERER_WIDTH  = 80;
 public final static int GOL_COLOR_RENDERER_HEIGHT = 25;
 public final static int GOL_COLOR_RENDERER_GAP    = 20;
 public final static int GOL_COLOR_RENDERER_INSETS = 6 ;
 
 //
 // Palette shape cell renderer constants
 //
 public final static int GOL_SHAPE_RENDERER_GAP    = 10;
 public final static int GOL_SHAPE_RENDERER_INSETS = 6 ;
 
 //
 // Statistics window drawing constants
 //
 public final static int GOL_STAT_WINDOW_DRAWING_GAP = 10;
 public final static int GOL_STAT_WINDOW_FONT_HEIGHT = 10 ;
 public final static int GOL_STAT_MAX_RECORDS = 8000;
  
 
   
 //
 // statistics constants
 //
 public final static int GOL_STAT_TENTENDY_UNCHANGED =  0;
 public final static int GOL_STAT_TENTENDY_INCREASE  =  1;
 public final static int GOL_STAT_TENTENDY_DECREASE  = -1;
 
 //
 // histogram constants
 //
 public final static int GOL_HISTOGRAM_MIN_BAR_WIDTH = 4;
 public final static int GOL_HISTOGRAM_MIN_BAR_GAP   = 3;
 
 //
 // magic stuff
 //
 public final static int GOL_STAT_DEFAULT_MAX_RECORDS = 5000;
 public final static int GOL_STAT_DEFAULT_MAX_DELAY   = 2500;

 //
 // keys for localized strings
 //
 public final static String GOL_WINDOW_CELL_MATRIX_TITLE = "windowCellMatrix.text"    ;
 public final static String GOL_WINDOW_MODIFIED_TITLE    = "windowModified.text"      ;
 public final static String GOL_FILE_ANNOTATION          = "fileChangeAnnotation.text";
 public final static String GOL_MENU_LOOKANDFEEL         = "menuLookAndFeel"          ;
 
 public final static String GOL_STAT_MSG_TENTENDY_UNCHANGED = "messageTendencyUnchanged";
 public final static String GOL_STAT_MSG_TENTENDY_INCREASE  = "messageTendencyIncreasing";
 public final static String GOL_STAT_MSG_TENTENDY_DECREASE  = "messageTendencyDecreasing";

 public final static String GOL_DIALOG_OPTIONS_YES    = "dialogItemYes.text"   ;
 public final static String GOL_DIALOG_OPTIONS_NO     = "dialogItemNo.text"    ;
 public final static String GOL_DIALOG_OPTIONS_OK     = "dialogItemOk.text"    ;
 public final static String GOL_DIALOG_OPTIONS_CANCEL = "dialogItemCancel.text";
 
 public final static String GOL_TITLE_COLOR           = "dialogTitleColor"         ;
 public final static String GOL_TITLE_INPUT           = "dialogTitleInput"         ;
 public final static String GOL_TITLE_CONFIRMATION    = "dialogTitleConfirmation"  ;
 public final static String GOL_TITLE_INFORMATION     = "dialogTitleInformation"   ; 
 public final static String GOL_TITLE_WARNING         = "dialogTitleWarning"       ; 
 public final static String GOL_TITLE_CELL_FILE_SAVE  = "dialogTitleCellSave"      ;
 public final static String GOL_TITLE_CELL_FILE_LOAD  = "dialogTitleCellLoad"      ;
 public final static String GOL_TITLE_PALETTE_SAVE    = "dialogTitlePaletteSave"   ;
 public final static String GOL_TITLE_PALETTE_LOAD    = "dialogTitlePaletteLoad"   ;
 public final static String GOL_TITLE_PROPERTIES_SAVE = "dialogTitlePropertiesSave";
 public final static String GOL_TITLE_PROPERTIES_LOAD = "dialogTitlePropertiesLoad";
 
 public final static String GOL_DIALOG_ABOUT               = "dialogMessageAbout"             ;
 public final static String GOL_DIALOG_TINY_VOICES         = "dialogMessageTinyVoices"        ;
 public final static String GOL_DIALOG_SHRINKING           = "dialogMessageShrinking"         ;
 public final static String GOL_DIALOG_RANDOM              = "dialogMessageRandom"            ;
 public final static String GOL_DIALOG_EXIT                = "dialogMessageExit"              ;
 public final static String GOL_DIALOG_CLEAR               = "dialogMessageClear"             ;
 public final static String GOL_DIALOG_AFTER_CLEAR         = "dialogMessageAfterClear"        ;
 public final static String GOL_DIALOG_LOAD                = "dialogMessageLoad"              ;
 public final static String GOL_DIALOG_FILE_EXISTS         = "dialogMessageFileExists"        ;
 public final static String GOL_DIALOG_CONFIRMATION_CANCEL = "dialogMessageConfirmationCancel";
 public final static String GOL_DIALOG_CONFIRMATION_OK     = "dialogMessageConfirmationOk"    ;
 public final static String GOL_DIALOG_SAVE_OK             = "dialogMessageSaveOk"            ;
 public final static String GOL_DIALOG_ENTER_SHAPE_NAME    = "dialogMessageEnterShapeName"    ;
 public final static String GOL_DIALOG_SCREENSHOT_RUNNING  = "dialogMessageScreenshotRunning" ;
 public final static String GOL_DIALOG_QUICKLOAD_FAILED    = "dialogMessageQuickLoadFailed"   ;
 public final static String GOL_DIALOG_QUICKSAVE_FAILED    = "dialogMessageQuickSaveFailed"   ;
 public final static String GOL_DIALOG_QUICKSAVE_NO_FILES  = "dialogMessageQuickSaveNoFiles"  ;
 public final static String GOL_DIALOG_CLEANUP_QUICKSAVE   = "dialogMessageCleanupQuickSave"  ;
 public final static String GOL_DIALOG_CLEANUP_SCREENSHOTS = "dialogMessageCleanupScreenshots";
 public final static String GOL_DIALOG_CLEANUP_EMPTY       = "dialogMessageCleanupEmpty"      ; 
 public final static String GOL_DIALOG_CLEANUP_SUCCESS     = "dialogMessageCleanupSuccess"    ; 
 public final static String GOL_DIALOG_CLEANUP_FAIL        = "dialogMessageCleanupFail"       ; 
 public final static String GOL_DIALOG_CLEANUP_WAIT        = "dialogMessageCleanupWait"       ;
 public final static String GOL_DIALOG_OOM                 = "dialogMessageOOM"               ;
 public final static String GOL_WINDOW_TITLE_QUICKSLOT     = "windowTitleQuickSlot"           ;

 //
 // I/O thread communication
 //
 public final static String GOL_IO_MESSAGE_OOM = "OutOfMemoryBug";
 
} // eoc
