/**
 * Game of Life
 * 
 */
package gridlife.core;



/**
 * Imports
 * 
 */
import gridlife.ui.GridLifeGuiConnector;

import java.awt.image.BufferedImage ;
import javax.imageio.ImageIO        ;
import java.io.File                 ;



/**
 * Saves a screenshot of the cell matrix to a file
 * 
 * @author Ulf Wagemann
 */
public class GridLifeSaveScreenshotThread extends Thread
{
 private GridLifeGuiConnector m_tGuiConnector; 
 private BufferedImage        m_tImage;
 private File                 m_tFile ;
 
 
 /**
  * Constructor
  * 
  * @param pa_sFileName      name of screenshotfile
  * @param pa_tImage         image to save
  * @param pa_tGuiConnector  caller to be notified when saving is done
  */
 public GridLifeSaveScreenshotThread(String pa_sFileName, BufferedImage pa_tImage, GridLifeGuiConnector pa_tGuiConnector)
 {
  m_tGuiConnector        = pa_tGuiConnector;
  m_tImage               = pa_tImage;
  m_tFile                = new File(pa_sFileName);
 }              
  
  
 /**
  * Thread.run : saves the screenshot
  * 
  * A FileChannel is used to wait until the file is completely written. Therefore,
  * we try to gain an exclusive lock on the file while waiting for this in a blocking 
  * manner.
  */
 @Override
 public final void run()
 {
  //
  // notify main program about thread start
  //
  if (null != m_tGuiConnector)
  {
   m_tGuiConnector.notifyIOThreadStarted(null);
  }
  
  //
  // write screenshot
  //
  if (null != m_tFile && null != m_tImage)
  {
   try
   {  
    ImageIO.setUseCache(false);
    ImageIO.write(m_tImage, "png", m_tFile);  
   }
   catch(Exception lc_tException)
   {}  
  }  

  //
  // notify main program about thread termination
  //  
  if (null != m_tGuiConnector)
  {
   m_tGuiConnector.notifyIOThreadTerminated(null);
  }
  
  //
  // cleanup image memory
  //  
  if (null != m_tImage)
  {
   try
   {
    m_tImage.getGraphics().dispose(); 
    m_tImage.flush();
    m_tImage = null;
   }
   catch (Exception lc_tException)
   {}
  }
 }
 

 
 
} // eoc
