/*
 * Game of Life
 */
package gridlife.ui;



/**
 * Imports
 * 
 */
import gridlife.core.GridLifeConstants          ;
import gridlife.core.GridLifeProperties         ;
import gridlife.core.GridLifeAgeHistogramManager;
import gridlife.color.GridLifeColorManager      ;
import gridlife.color.GridLifeColorSet          ;

import java.awt.Dimension     ;
import java.awt.Color         ;
import java.awt.Rectangle     ;
import java.awt.Graphics2D    ;
import javax.swing.JScrollPane;




/**
 * This class draw the age histogram
 * 
 * @author Ulf Wagemann
 */
public class GridLifeAgeHistogramPaintPanel extends GridLifePaintPanel
{
 protected GridLifeAgeHistogramManager m_tAgeHistogramManager;
 protected GridLifeColorManager        m_tColorManager       ;

 
 
 /**
  * Constructor 
  * 
  * @param pa_tScrollPane    scrollpane
  * @param pa_tRuleset       current properties
  */
 public GridLifeAgeHistogramPaintPanel(JScrollPane                 pa_tScrollPane         , 
                                       GridLifeProperties          pa_tProperties         , 
                                       GridLifeAgeHistogramManager pa_tAgeHistogramManager,
                                       GridLifeColorManager        pa_tColorManager       )
 {
  super(pa_tScrollPane, pa_tProperties);
  setDoubleBuffered(true);
  m_tColorManager        = pa_tColorManager       ;
  m_tAgeHistogramManager = pa_tAgeHistogramManager;
 }
  
 

 /**
  * Does the custom painting on the given graphics object.
  * 
  * @param pa_tGraphics  Paint on it!
  */
 public void paintCustom(Graphics2D pa_tGraphics)
 {
  Rectangle lc_tRect  = null;
  int       lc_iValue = 0;
  
  //
  // get visible rect for later comparisions
  //
  if (null != m_tScrollPane)
  {
   if (null != m_tScrollPane.getViewport())
   {
    lc_tRect = m_tScrollPane.getViewport().getViewRect();
   }
  }

  //
  // only continue with valid objects
  //
  if (null != pa_tGraphics && null != lc_tRect)
  {
   pa_tGraphics.setColor(m_tColorBackground);
   pa_tGraphics.setPaintMode();
   pa_tGraphics.setStroke(m_tLineStrokeSolid);
   pa_tGraphics.fillRect(0, 0, lc_tRect.width, lc_tRect.height);
  
   //
   // draw grid
   //
   drawGrid(pa_tGraphics, lc_tRect);   
   
   //
   // draw age records
   //
   if (0 < (lc_iValue = drawRecords(pa_tGraphics, lc_tRect)))
   {
    m_tScrollPane.setPreferredSize(new Dimension(lc_iValue, lc_tRect.height)); 
    m_tScrollPane.revalidate();
   }
  } 
 }
  


 /**
  * Draws the grid
  * 
  * @param pa_tGraphics2D    Graphics object to draw on
  * @param pa_tRect          Visible rectangle
  */
 private void drawGrid(Graphics2D pa_tGraphics2D, Rectangle pa_tRect)
 {
  int lc_iMaxHeight           = 0;
  int lc_iHalfMaxHeight       = 0;
  int lc_iQuarterMaxHeight    = 0;
  int lc_iZeroLine            = 0;
  
  if (null != pa_tGraphics2D && null != pa_tRect && null != m_tAgeHistogramManager && null != m_tProperties)
  {
   lc_iMaxHeight        = pa_tRect.height - (2 * GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP);
   lc_iHalfMaxHeight    = lc_iMaxHeight / 2  ;
   lc_iQuarterMaxHeight = lc_iMaxHeight / 4  ;
   lc_iZeroLine         = GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iMaxHeight;
   
   pa_tGraphics2D.setPaintMode();
   pa_tGraphics2D.setStroke(m_tLineStrokeDotted);
   pa_tGraphics2D.setRenderingHints(m_tRenderingHints);
   
   //
   // paint 100% line and text below
   //
   pa_tGraphics2D.setColor(m_tStatisticsLineColor);
   pa_tGraphics2D.drawLine(0, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP, pa_tRect.width, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP);
   pa_tGraphics2D.setColor(Color.black);
  
   //
   // paint 75% line 
   //
   pa_tGraphics2D.setColor(m_tStatisticsLineColor);
   pa_tGraphics2D.drawLine(0, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iQuarterMaxHeight, pa_tRect.width, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iQuarterMaxHeight);

   //
   // paint 50% line
   //
   pa_tGraphics2D.setColor(m_tStatisticsLineColor);
   pa_tGraphics2D.drawLine(0, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iHalfMaxHeight, pa_tRect.width, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iHalfMaxHeight);
   pa_tGraphics2D.setColor(Color.black);

   //
   // paint 25% line 
   //
   pa_tGraphics2D.setColor(m_tStatisticsLineColor);
   pa_tGraphics2D.drawLine(0, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iHalfMaxHeight + lc_iQuarterMaxHeight, pa_tRect.width, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iHalfMaxHeight + lc_iQuarterMaxHeight);

   //
   // paint 0% line
   //
   pa_tGraphics2D.setColor(m_tStatisticsLineColor);
   pa_tGraphics2D.drawLine(0, lc_iZeroLine, pa_tRect.width, lc_iZeroLine);
   pa_tGraphics2D.setColor(Color.black);
   pa_tGraphics2D.setStroke(m_tLineStrokeSolid);
  }
 }
  
   
   

 /**
  * Draws the grid
  * 
  * @param pa_tGraphics2D    Graphics object to draw on
  * @param pa_tRect          Visible rectangle
  */
 private int drawRecords(Graphics2D pa_tGraphics2D, Rectangle pa_tRect)
 {
  int lc_iMaxCells  = 0;
  int lc_iDrawX1    = 0;
  int lc_iDrawY1    = 0;
  int lc_iI         = 0;
  int lc_iValue     = 0;
  
  int lc_iGap          = 0;
  int lc_iMaxHeight    = 0;
  int lc_iMaxWidth     = 0;
  int lc_iZeroLine     = 0;
  int lc_iBestBarWidth = 0;
  int lc_iDrawAreaX    = 0;
  
  float lc_fPercentRecordAmount = 0;
  float lc_fPercentDrawAmount   = 0;  
  int   lc_iBarAreaWidth        = 0;
  
  int[] lc_tAges = null;
  int[] lc_ColorSetAges = null;
  
  GridLifeColorSet lc_tColorSet = null;
  Rectangle lc_tRect = new Rectangle(pa_tRect);
  
  synchronized(m_tAgeHistogramManager)
  {
   if (0 < m_tAgeHistogramManager.getRecordAmount())
   {
    //
    // draw age records. make sure to synchronize on histogram mananager
    //
    if (null != (lc_tAges = m_tAgeHistogramManager.getKeys()))
    {
     lc_iMaxCells  = m_tAgeHistogramManager.sum();

     //
     // we need to catch the case that computing threads may desync the drawing order. in that case,
     // we receive a value of zero for lc_iMaxCells, which we catch
     //
     if (0 < lc_iMaxCells && null != m_tColorManager) 
     {
      if (null != (lc_tColorSet = m_tColorManager.getActiveSet()))
      {
       //
       // compute settings for drawing
       //        
       lc_iMaxWidth  = lc_tRect.width  - (2 * GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP);
       lc_iMaxHeight = lc_tRect.height - (2 * GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP);
       
       lc_iZeroLine  = GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iMaxHeight        ;
       lc_iDrawX1    = GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP;
  
       //
       // no colors, no shiny display...
       //
       if (0 < lc_tColorSet.getAmount())
       {
        lc_iGap          = (lc_tColorSet.getAmount() - 1) * GridLifeConstants.GOL_HISTOGRAM_MIN_BAR_GAP;
        lc_iBarAreaWidth = lc_iMaxWidth - lc_iGap; 
        lc_iBestBarWidth = (lc_iBarAreaWidth / lc_tColorSet.getAmount());
       
        //
        // if we have some pixels left, we try centering the  whole histogram nicely by computing an offset :-)
        //
        lc_iDrawAreaX = (lc_iBestBarWidth * lc_tColorSet.getAmount()) + lc_iGap;
        
        if (lc_iMaxWidth - lc_iDrawAreaX > 0)
        {
         lc_iDrawX1 += (int) ((lc_iMaxWidth - lc_iDrawAreaX) +0.5f)/2; 
        }
        
        //
        // we iterate over the colorset to make sure that zero-values do not result in "moving" boxes in the display
        // and instead have fixed positions to paint each age class on
        //
        if (null != (lc_ColorSetAges = m_tColorManager.getActiveAges()))
        {
         for (lc_iI = 0; lc_iI < lc_tColorSet.getAmount(); lc_iI++)
         {
          lc_iValue = m_tAgeHistogramManager.get(lc_ColorSetAges[lc_iI]);
          
          if (0 < lc_iValue)
          {
           lc_fPercentRecordAmount = (lc_iValue * 100) / lc_iMaxCells               ; // % of cells according to amount of living (!) cells
           lc_fPercentDrawAmount   = (lc_fPercentRecordAmount * lc_iMaxHeight) / 100; // % of pixels according to the maximum drawing height for bars
           lc_iDrawY1              = lc_iZeroLine - (int) lc_fPercentDrawAmount       ; // top left corner coordinate of bar         
          
           if (lc_iDrawY1 != lc_iZeroLine)
           {
            //
            // draw a nice bar. start with bar rect
            //
            pa_tGraphics2D.setColor(Color.black);
            pa_tGraphics2D.drawRect(lc_iDrawX1, lc_iDrawY1, lc_iBestBarWidth, (int) lc_fPercentDrawAmount);
            
            //
            // bar fill
            //
            pa_tGraphics2D.setColor(lc_tColorSet.getColor(lc_ColorSetAges[lc_iI]));
            pa_tGraphics2D.fillRect(lc_iDrawX1 + 1, lc_iDrawY1 + 1, lc_iBestBarWidth - 1, -1 + (int) lc_fPercentDrawAmount);
           
            //
            // shadow
            //
            pa_tGraphics2D.setColor(m_tShadowColor);
            pa_tGraphics2D.drawLine(lc_iDrawX1 + lc_iBestBarWidth + 1, lc_iDrawY1 + 1, 
                                    lc_iDrawX1 + lc_iBestBarWidth + 1, lc_iDrawY1 + (int) lc_fPercentDrawAmount);
            
           }
           else
           {
            //
            // just draw the color line
            //
            pa_tGraphics2D.setColor(lc_tColorSet.getColor(lc_ColorSetAges[lc_iI]));
            pa_tGraphics2D.drawLine(lc_iDrawX1, lc_iDrawY1, lc_iDrawX1 + lc_iBestBarWidth, lc_iDrawY1);
           }
          }
          lc_iDrawX1 += lc_iBestBarWidth + GridLifeConstants.GOL_HISTOGRAM_MIN_BAR_GAP;
         }
        }
       }
      }
     }
    }
   }
  }
  return 0;
 }
 
 
 
 /** 
  * Sets the panel's size
  * 
  */ 
 private void resizePanel(Dimension pa_tNewSize)
 {
  if (null != pa_tNewSize) 
  {
   setPreferredSize(pa_tNewSize);
   setSize(pa_tNewSize);
  } 
 }
 
 

 /**
  * Check for enlargement needed
  * 
  * @param pa_tColorSet
  * @return 0, if no enlargement, otherwise new width to resize to
  */
 public final int checkForEnlargement(GridLifeColorSet pa_tColorSet)
 {
  int lc_iMinWidth = 0;
  Rectangle lc_tRect = null;
  
  if (null != m_tScrollPane)
  {
   if (null != m_tScrollPane.getViewport())
   {
    lc_tRect = m_tScrollPane.getViewport().getViewRect();
   }
  }
  
  //
  // check if we need to enlarge
  //
  if (null != lc_tRect && null != pa_tColorSet)
  {
   lc_iMinWidth = (2 * GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP)                            + 
                  ((pa_tColorSet.getAmount() - 1) * GridLifeConstants.GOL_HISTOGRAM_MIN_BAR_GAP) +
                  (pa_tColorSet.getAmount()       * GridLifeConstants.GOL_HISTOGRAM_MIN_BAR_WIDTH);
   if (lc_iMinWidth > lc_tRect.width)        
   {
    resizePanel(new Dimension(lc_iMinWidth, lc_tRect.height)); 
    return lc_iMinWidth;
   }
  }       
  return 0; 
 }
 
} // eoc
