/*
 * Game of Life
 * 
 */
package gridlife.ui;

import java.awt.Component              ;
import javax.swing.SwingUtilities      ;
import javax.swing.JMenu               ;
import javax.swing.ButtonGroup         ;
import javax.swing.JRadioButtonMenuItem;

import javax.swing.UIManager                ;
import javax.swing.UIManager.LookAndFeelInfo;
import javax.swing.LookAndFeel              ;



/**
 * Creates a menu from the installed look and feels, stores detected look and feels and lets the user choose from them.
 * 
 * @author Ulf Wagemann
 */
public class GridLifeLookAndFeelMenu extends JMenu 
{
 private Component m_tRootComponent;
 private boolean   m_bHasEntries   ;
 
 private JRadioButtonMenuItem m_tMenuItems[]  ;
 private LookAndFeelInfo      m_tInstalledLF[];
 private String               m_sSelectedMenu ;
 
 
 /**
  * Constructor
  * 
  * @param pa_sName           Menu title
  * @param pa_tRootComponent  Root window
  */
 public GridLifeLookAndFeelMenu(String pa_sName, Component pa_tRootComponent)
 {
  super(pa_sName);

  m_tInstalledLF   = UIManager.getInstalledLookAndFeels();
  m_tRootComponent = pa_tRootComponent;
  m_bHasEntries    = false            ;  
  m_sSelectedMenu  = null;
  
  final LookAndFeel     lc_tCurrentLF     = UIManager.getLookAndFeel();
  final String          lc_sCurrentLFId   = (null != lc_tCurrentLF ? lc_tCurrentLF.getID() : null);

  JRadioButtonMenuItem  lc_tMenuItemLF    = null;
  ButtonGroup           lc_tButtonGroup   = new ButtonGroup();
  
  int lc_iI        = 0;
  int lc_iLength   = 0;
  int lc_iCount    = 0;
  
  if (null != m_tInstalledLF)
  {
   if (0 < (lc_iLength =  m_tInstalledLF.length))
   {
    if (null != (m_tMenuItems = new JRadioButtonMenuItem[lc_iLength])) 
    {
     for (lc_iI =0 ; lc_iI < lc_iLength; lc_iI++)
     {
      if (null != (lc_tMenuItemLF = new JRadioButtonMenuItem()))
      {
       final int lc_iPosition = lc_iI; // ugly, but well...
       
       lc_tMenuItemLF.setText(m_tInstalledLF[lc_iI].getName());  
       lc_tMenuItemLF.addActionListener(new java.awt.event.ActionListener() 
                                        {
	                                     public void actionPerformed(java.awt.event.ActionEvent evt) 
                                         {
                                          SwingUtilities.invokeLater(new Runnable() 
                                          {
                                           public void run() 
                                           {
                                            selectLF(lc_iPosition); 
                                           }
	                                      });
                                         }
                                        });
       
       lc_tButtonGroup.add(lc_tMenuItemLF);
       m_tMenuItems[lc_iCount] = lc_tMenuItemLF;
       this.add(lc_tMenuItemLF);
       
       if (null != lc_sCurrentLFId)
       {
        if (lc_sCurrentLFId.equals(m_tInstalledLF[lc_iI].getName()))
        {
         lc_tMenuItemLF.setSelected(true); 
         m_sSelectedMenu = m_tInstalledLF[lc_iI].getName();
        }
       }
       lc_iCount++;
      }  
     } // for
    }
    m_bHasEntries = (0 < lc_iCount);
   }
  }
 }
 
 
 
 /**
  * Checks whether the menu has entries
  * 
  * @return 
  */
 public final boolean isLFMenuValid() {return m_bHasEntries;}
 
 
 
 /**
  * Returns the name of the selected menu entry
  * @return 
  */
 public final String getSelectedLF() {return m_sSelectedMenu;}
 
 
 
 /**
  * Selects the given LF
  * 
  * @param pa_sName    LF menu name
  */
 public final void selectLF(String pa_sName)
 {
  boolean lc_bDone   = false;
  int     lc_iLength = 0   ;
  int     lc_iI      = 0   ;
  
  if (null != m_tInstalledLF && null != m_tMenuItems && null != pa_sName)
  {
   if (0 < (lc_iLength =  m_tInstalledLF.length))
   {
    while (false == lc_bDone && lc_iI < lc_iLength)
    {
     lc_bDone = (m_tInstalledLF[lc_iI].getName().equals(pa_sName));
     if (true == lc_bDone)
     {
      m_tMenuItems[lc_iI].setSelected(true); 
      selectLF(lc_iI);
     }
     lc_iI++;
    } // while
    
   }
  }
 }
 
 
 
 /**
  * Selects the given LF
  * 
  * @param pa_iPosition   array/(menu index
  */
 private void selectLF(int pa_iPosition)
 {
  int     lc_iLength = 0   ;

  if (null != m_tInstalledLF)
  {
   if (0 < (lc_iLength =  m_tInstalledLF.length))
   {
    if (0 <= pa_iPosition && lc_iLength > pa_iPosition)
    {
     try 
     {
      m_sSelectedMenu = m_tInstalledLF[pa_iPosition].getName();
      UIManager.setLookAndFeel(m_tInstalledLF[pa_iPosition].getClassName());
      SwingUtilities.updateComponentTreeUI(m_tRootComponent);
     }
     catch (Exception lc_tException) 
     {}
    }
   }
  } 
 }
 
 
}
