/**
 * Game of Life
 * 
 */
package gridlife.ui;

import org.jdesktop.application.Action;



/**
 * Main window for the MDI application,
 * 
 * @author Ulf Wagemann
 */
public class GridLifeMainWindow extends javax.swing.JFrame {

  private GridLifeGuiConnector m_tGuiConnector;

  
  
  /**
   * Constructor
   * 
   * @param pa_tGuiConnector    GuiConnector object
   */
  public GridLifeMainWindow(GridLifeGuiConnector pa_tGuiConnector) 
  {
   m_tGuiConnector = pa_tGuiConnector;
   initComponents();
   setContentPane(desktopPane);
  }


  /**
   * Sets the checkboxes for the subwindows to the given values
   * 
   * @param lc_bProperties          true, if the properties window checkbox should be checked
   * @param lc_bStatistics          true, if the statistics window checkbox should be checked
   * @param lc_bShapePalette        true, if the shape palette window checkbox should be checked 
   * @param lc_bColor               true, if the color window checkbox should be checked
   * @param lc_bPaletteEditor       true, if the shape palette editor window checkbox should be checked 
   */
  public void setWindowMenuCheckBoxes(boolean lc_bProperties, boolean lc_bStatistics, boolean lc_bShapePalette, boolean lc_bColor, boolean lc_bPaletteEditor)
  {
   jCheckBoxMenuItemProperties.setState   (lc_bProperties   ); 
   jCheckBoxMenuItemStatistics.setState   (lc_bStatistics   ); 
   jCheckBoxMenuItemShapes.setState       (lc_bShapePalette ); 
   jCheckBoxMenuItemColor.setState        (lc_bColor        ); 
   jCheckBoxMenuItemPaletteEditor.setState(lc_bPaletteEditor);
  }

  
  
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  @SuppressWarnings("unchecked")
  
  
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        desktopPane = new javax.swing.JDesktopPane();
        menuBar = new javax.swing.JMenuBar();
        fileMenu = new javax.swing.JMenu();
        loadMenuItem = new javax.swing.JMenuItem();
        saveMenuItem = new javax.swing.JMenuItem();
        clearMenuItem = new javax.swing.JMenuItem();
        jSeparator2 = new javax.swing.JPopupMenu.Separator();
        screenshotMenuItem = new javax.swing.JMenuItem();
        quicksaveMenuItem = new javax.swing.JMenuItem();
        jSeparator3 = new javax.swing.JPopupMenu.Separator();
        exitMenuItem = new javax.swing.JMenuItem();
        windowMenu = new javax.swing.JMenu();
        jCheckBoxMenuItemColor = new javax.swing.JCheckBoxMenuItem();
        jCheckBoxMenuItemProperties = new javax.swing.JCheckBoxMenuItem();
        jCheckBoxMenuItemShapes = new javax.swing.JCheckBoxMenuItem();
        jCheckBoxMenuItemPaletteEditor = new javax.swing.JCheckBoxMenuItem();
        jCheckBoxMenuItemStatistics = new javax.swing.JCheckBoxMenuItem();
        jSeparator1 = new javax.swing.JPopupMenu.Separator();
        jMenuItemArrange = new javax.swing.JMenuItem();
        helpMenu = new javax.swing.JMenu();
        aboutMenuItem = new javax.swing.JMenuItem();

        setDefaultCloseOperation(javax.swing.WindowConstants.DO_NOTHING_ON_CLOSE);
        java.util.ResourceBundle bundle = java.util.ResourceBundle.getBundle("gridlife/ui/resources/GridLifeMainWindow"); // NOI18N
        setTitle(bundle.getString("Form.title")); // NOI18N
        setName("Form"); // NOI18N

        desktopPane.setName("desktopPane"); // NOI18N

        menuBar.setName("menuBar"); // NOI18N

        fileMenu.setMnemonic('f');
        fileMenu.setText(bundle.getString("fileMenu.text")); // NOI18N
        fileMenu.setActionCommand(bundle.getString("fileMenu.text")); // NOI18N
        fileMenu.setName("fileMenu"); // NOI18N

        loadMenuItem.setMnemonic('o');
        loadMenuItem.setText(bundle.getString("loadMenuItem.text")); // NOI18N
        loadMenuItem.setActionCommand(bundle.getString("loadMenuItem.actionCommand")); // NOI18N
        loadMenuItem.setName("loadMenuItem"); // NOI18N
        loadMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                handleEventMenuLoad(evt);
            }
        });
        fileMenu.add(loadMenuItem);

        saveMenuItem.setMnemonic('s');
        saveMenuItem.setText(bundle.getString("saveMenuItem.text")); // NOI18N
        saveMenuItem.setActionCommand(bundle.getString("saveMenuItem.actionCommand")); // NOI18N
        saveMenuItem.setName("saveMenuItem"); // NOI18N
        saveMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                handleEventMenuSave(evt);
            }
        });
        fileMenu.add(saveMenuItem);

        clearMenuItem.setMnemonic('r');
        clearMenuItem.setText(bundle.getString("clearMenuItem.text")); // NOI18N
        clearMenuItem.setActionCommand(bundle.getString("clearMenuItem.actionCommand")); // NOI18N
        clearMenuItem.setName("clearMenuItem"); // NOI18N
        clearMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                handleEventMenuClear(evt);
            }
        });
        fileMenu.add(clearMenuItem);

        jSeparator2.setName("jSeparator2"); // NOI18N
        fileMenu.add(jSeparator2);

        screenshotMenuItem.setMnemonic('o');
        screenshotMenuItem.setText(bundle.getString("screenshotMenuItem.text")); // NOI18N
        screenshotMenuItem.setActionCommand(bundle.getString("cleanupScreenshotsMenuItem.actionCommand")); // NOI18N
        screenshotMenuItem.setName("screenshotMenuItem"); // NOI18N
        screenshotMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                handleEventMenuScreenshot(evt);
            }
        });
        fileMenu.add(screenshotMenuItem);

        quicksaveMenuItem.setMnemonic('o');
        quicksaveMenuItem.setText(bundle.getString("quicksaveMenuItem.text")); // NOI18N
        quicksaveMenuItem.setActionCommand(bundle.getString("cleanupQuickSaveMenuItem.actionCommand")); // NOI18N
        quicksaveMenuItem.setName("quicksaveMenuItem"); // NOI18N
        quicksaveMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                handleEventMenuQuickSaves(evt);
            }
        });
        fileMenu.add(quicksaveMenuItem);

        jSeparator3.setName("jSeparator3"); // NOI18N
        fileMenu.add(jSeparator3);

        exitMenuItem.setMnemonic('x');
        exitMenuItem.setText(bundle.getString("exitMenuItem.text")); // NOI18N
        exitMenuItem.setActionCommand(bundle.getString("exitMenuItem.actionCommand")); // NOI18N
        exitMenuItem.setName("exitMenuItem"); // NOI18N
        exitMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                handleEventMenuExit(evt);
            }
        });
        fileMenu.add(exitMenuItem);

        menuBar.add(fileMenu);

        windowMenu.setText(bundle.getString("windowMenu.text")); // NOI18N
        windowMenu.setActionCommand(bundle.getString("windowMenu.text")); // NOI18N
        windowMenu.setName("windowMenu"); // NOI18N

        javax.swing.ActionMap actionMap = org.jdesktop.application.Application.getInstance(gridlife.core.GridLifeApp.class).getContext().getActionMap(GridLifeMainWindow.class, this);
        jCheckBoxMenuItemColor.setAction(actionMap.get("menuActionWindowColor")); // NOI18N
        jCheckBoxMenuItemColor.setSelected(true);
        jCheckBoxMenuItemColor.setText(bundle.getString("jCheckBoxMenuItemColor.text")); // NOI18N
        jCheckBoxMenuItemColor.setActionCommand(bundle.getString("jCheckBoxMenuItemColor.actionCommand")); // NOI18N
        jCheckBoxMenuItemColor.setName("jCheckBoxMenuItemColor"); // NOI18N
        windowMenu.add(jCheckBoxMenuItemColor);

        jCheckBoxMenuItemProperties.setAction(actionMap.get("menuActionWindowProperties")); // NOI18N
        jCheckBoxMenuItemProperties.setText(bundle.getString("jCheckBoxMenuItemProperties.text")); // NOI18N
        jCheckBoxMenuItemProperties.setActionCommand(bundle.getString("jCheckBoxMenuItemProperties.actionCommand")); // NOI18N
        jCheckBoxMenuItemProperties.setName("jCheckBoxMenuItemProperties"); // NOI18N
        windowMenu.add(jCheckBoxMenuItemProperties);

        jCheckBoxMenuItemShapes.setAction(actionMap.get("menuActionWindowsShapePalette")); // NOI18N
        jCheckBoxMenuItemShapes.setText(bundle.getString("jCheckBoxMenuItemShapes.text")); // NOI18N
        jCheckBoxMenuItemShapes.setActionCommand(bundle.getString("jCheckBoxMenuItemShapes.actionCommand")); // NOI18N
        jCheckBoxMenuItemShapes.setName("jCheckBoxMenuItemShapes"); // NOI18N
        windowMenu.add(jCheckBoxMenuItemShapes);

        jCheckBoxMenuItemPaletteEditor.setAction(actionMap.get("menuActionWindowPaletteEditor")); // NOI18N
        jCheckBoxMenuItemPaletteEditor.setText(bundle.getString("jCheckBoxMenuItemPaletteEditor.text")); // NOI18N
        jCheckBoxMenuItemPaletteEditor.setActionCommand(bundle.getString("jCheckBoxMenuItemPaletteEditor.actionCommand")); // NOI18N
        jCheckBoxMenuItemPaletteEditor.setName("jCheckBoxMenuItemPaletteEditor"); // NOI18N
        windowMenu.add(jCheckBoxMenuItemPaletteEditor);

        jCheckBoxMenuItemStatistics.setAction(actionMap.get("menuActionWindowStatistics")); // NOI18N
        jCheckBoxMenuItemStatistics.setText(bundle.getString("jCheckBoxMenuItemStatistics.text")); // NOI18N
        jCheckBoxMenuItemStatistics.setActionCommand(bundle.getString("jCheckBoxMenuItemStatistics.actionCommand")); // NOI18N
        jCheckBoxMenuItemStatistics.setName("jCheckBoxMenuItemStatistics"); // NOI18N
        windowMenu.add(jCheckBoxMenuItemStatistics);

        jSeparator1.setName("jSeparator1"); // NOI18N
        windowMenu.add(jSeparator1);

        jMenuItemArrange.setAction(actionMap.get("menuActionWindowArrange")); // NOI18N
        jMenuItemArrange.setText(bundle.getString("jMenuItemArrange.text")); // NOI18N
        jMenuItemArrange.setActionCommand(bundle.getString("jMenuItemArrange.actionCommand")); // NOI18N
        jMenuItemArrange.setName("jMenuItemArrange"); // NOI18N
        windowMenu.add(jMenuItemArrange);

        menuBar.add(windowMenu);

        helpMenu.setMnemonic('h');
        helpMenu.setText(bundle.getString("helpMenu.text")); // NOI18N
        helpMenu.setActionCommand(bundle.getString("helpMenu.text")); // NOI18N
        helpMenu.setName("helpMenu"); // NOI18N

        aboutMenuItem.setMnemonic('a');
        aboutMenuItem.setText(bundle.getString("aboutMenuItem.text")); // NOI18N
        aboutMenuItem.setActionCommand(bundle.getString("aboutMenuItem.actionCommand")); // NOI18N
        aboutMenuItem.setName("aboutMenuItem"); // NOI18N
        aboutMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                handleActionMenuAbout(evt);
            }
        });
        helpMenu.add(aboutMenuItem);

        menuBar.add(helpMenu);

        setJMenuBar(menuBar);

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(desktopPane, javax.swing.GroupLayout.DEFAULT_SIZE, 735, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(desktopPane, javax.swing.GroupLayout.DEFAULT_SIZE, 546, Short.MAX_VALUE)
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents
/********************************************* event handling methods ****************************************************/
    private void handleActionMenuAbout(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_handleActionMenuAbout
      if (null != m_tGuiConnector) m_tGuiConnector.handleMenuAbout();
    }//GEN-LAST:event_handleActionMenuAbout

    private void handleEventMenuExit(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_handleEventMenuExit
      if (null != m_tGuiConnector) m_tGuiConnector.handleMenuExit();
    }//GEN-LAST:event_handleEventMenuExit

private void handleEventMenuClear(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_handleEventMenuClear
if (null != m_tGuiConnector) m_tGuiConnector.handleMenuClear();  
}//GEN-LAST:event_handleEventMenuClear

private void handleEventMenuSave(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_handleEventMenuSave
if (null != m_tGuiConnector) m_tGuiConnector.handleMenuSave();  
}//GEN-LAST:event_handleEventMenuSave

private void handleEventMenuLoad(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_handleEventMenuLoad
if (null != m_tGuiConnector) m_tGuiConnector.handleMenuLoad();  
}//GEN-LAST:event_handleEventMenuLoad

  private void handleEventMenuScreenshot(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_handleEventMenuScreenshot
    // TODO add your handling code here:
if (null != m_tGuiConnector) m_tGuiConnector.handleMenuCleanupScreenshots();  
  }//GEN-LAST:event_handleEventMenuScreenshot

  private void handleEventMenuQuickSaves(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_handleEventMenuQuickSaves
    // TODO add your handling code here:
if (null != m_tGuiConnector) m_tGuiConnector.handleMenuCleanupQuickSaves();  
  }//GEN-LAST:event_handleEventMenuQuickSaves

  @Action
  public void menuActionWindowProperties() {if (null != m_tGuiConnector) m_tGuiConnector.handleMenuWindowProperties();}

  @Action
  public void menuActionWindowStatistics() {if (null != m_tGuiConnector) m_tGuiConnector.handleMenuWindowStatistics();}

  @Action
  public void menuActionWindowsShapePalette() {if (null != m_tGuiConnector) m_tGuiConnector.handleMenuWindowShapePalette();}

  @Action
  public void menuActionWindowColor() {if (null != m_tGuiConnector) m_tGuiConnector.handleMenuWindowColor();}
   
  @Action
  public void menuActionWindowPaletteEditor()  {if (null != m_tGuiConnector) m_tGuiConnector.handleMenuWindowPaletteEditor();}
  
  @Action
  public void menuActionWindowArrange() {if (null != m_tGuiConnector) m_tGuiConnector.handleMenuWindowArrange();}
  
  
  /***************************************** getters for UI objects *****************************************************/
  public final javax.swing.JMenuItem getMenuItemLoad()  {return loadMenuItem; }
  public final javax.swing.JMenuItem getMenuItemClear() {return clearMenuItem;}
  public final javax.swing.JMenuItem getMenuItemSave()  {return saveMenuItem; }
  public final javax.swing.JMenuItem getMenuItemAbout() {return aboutMenuItem;}
  
  public final javax.swing.JMenuItem getMenuItemCleanupScreenshots()  {return screenshotMenuItem; }
  public final javax.swing.JMenuItem getMenuItemCleanupQuickSaves()   {return quicksaveMenuItem ; }
  public final javax.swing.JMenuBar  getWindowMenuBar() {return menuBar;      }
  
  
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JMenuItem aboutMenuItem;
    private javax.swing.JMenuItem clearMenuItem;
    private javax.swing.JDesktopPane desktopPane;
    private javax.swing.JMenuItem exitMenuItem;
    private javax.swing.JMenu fileMenu;
    private javax.swing.JMenu helpMenu;
    private javax.swing.JCheckBoxMenuItem jCheckBoxMenuItemColor;
    private javax.swing.JCheckBoxMenuItem jCheckBoxMenuItemPaletteEditor;
    private javax.swing.JCheckBoxMenuItem jCheckBoxMenuItemProperties;
    private javax.swing.JCheckBoxMenuItem jCheckBoxMenuItemShapes;
    private javax.swing.JCheckBoxMenuItem jCheckBoxMenuItemStatistics;
    private javax.swing.JMenuItem jMenuItemArrange;
    private javax.swing.JPopupMenu.Separator jSeparator1;
    private javax.swing.JPopupMenu.Separator jSeparator2;
    private javax.swing.JPopupMenu.Separator jSeparator3;
    private javax.swing.JMenuItem loadMenuItem;
    private javax.swing.JMenuBar menuBar;
    private javax.swing.JMenuItem quicksaveMenuItem;
    private javax.swing.JMenuItem saveMenuItem;
    private javax.swing.JMenuItem screenshotMenuItem;
    private javax.swing.JMenu windowMenu;
    // End of variables declaration//GEN-END:variables
}
