/**
 * Game of Life
 */
package gridlife.ui;



/**
 * Imports
 * 
 */
import gridlife.core.GridLifeConstants;
import gridlife.core.GridLifeProperties;



/** 
 * Window for properties.
 * 
 * 20.01.2012  inserted setAutoCommit()
 * 
 * @author Ulf Wagemann
 */
public class GridLifePropertiesWindow extends javax.swing.JInternalFrame 
{
 private GridLifeGuiConnector m_tGuiConnector;
  

  
  /**
   * Constructor
   * 
   * @param pa_tGuiConnector    GuiConnector object
   */
  public GridLifePropertiesWindow(GridLifeGuiConnector pa_tGuiConnector) 
  {
   initComponents();
   m_tGuiConnector = pa_tGuiConnector;
    
   //
   // get rid of a thousands separator in the spinners' editors
   //
   jSpinnerDelay.setEditor              (new javax.swing.JSpinner.NumberEditor(jSpinnerDelay              , "#"));
   jSpinnerColumns.setEditor            (new javax.swing.JSpinner.NumberEditor(jSpinnerColumns            , "#"));
   jSpinnerRows.setEditor               (new javax.swing.JSpinner.NumberEditor(jSpinnerRows               , "#"));
   jSpinnerScreenshotPixelSize.setEditor(new javax.swing.JSpinner.NumberEditor(jSpinnerScreenshotPixelSize, "#"));
   
   //
   // make sure that the spinner's formatters auto-commit valid inputs
   //
   setAutoCommit(jSpinnerColumns            );
   setAutoCommit(jSpinnerRows               );
   setAutoCommit(jSpinnerDelay              );
   setAutoCommit(jSpinnerScreenshotPixelSize);
  }

  
  
  /**
   * Returns new properties based on the current settings
   * 
   * @return null in case of error, otherwise new properties
   */
  public final GridLifeProperties getProperties()
  {
    return new GridLifeProperties(getRulesStayAlive()  ,
                                  getRulesBecomeAlive(),
                                  getNeighbourhood()   , 
                                  getColumns()         , 
                                  getRows()            ,   
                                  getTopology()        , 
                                  getDelay()           ,
                                  getShowHelpLines()   ,
                                  getShowGridLines()   ,
                                  getShowCellHiliteLines(),
                                  getShowCellBorders()    ,
                                  getColorBg()            ,
                                  getColorGridLines()     ,
                                  getColorHelpLines()     ,
                                  getColorCellHilightLines()  ,
                                  getColorCellBorders()       ,
                                  getColorCellSelectionFrame(),
                                  getColorCellSelectionArea() ,
                                  getColorCellInsertionFrame(),
                                  getColorCellInsertionArea() ,
                                  getScreenshotCellSize()     ,
                                  getInvertMouseWheel()       );
   }
  
  
  
  /**
   * Returns the neighbourhoodtype
   * 
   * @return   -1 in case of error, 0 if VonNeumann is selcted, 1 if Moore is selected
   */
  public final int getNeighbourhood()
  {
   return (null != jComboBoxNeighbourhood ? jComboBoxNeighbourhood.getSelectedIndex() : -1);
  }
  
  
  
  /** 
   * Returns whether cell hilights should be drawn
   * 
   * @return   -1 in case of error, 0 if cell borders should be drawn, 0 otherwise
   */
  public final int getShowCellHiliteLines()
  {
   return (null != jComboBoxCellHiliteLines ? jComboBoxCellHiliteLines.getSelectedIndex() : -1);  
  }

  
  
  /** 
   * Returns whether cell borders should be drawn
   * 
   * @return   -1 in case of error, 0 if cell borders should be drawn, 1 otherwise
   */  
  public final int getShowCellBorders()
  {
   return (null != jComboBoxCellBorders ? jComboBoxCellBorders.getSelectedIndex() : -1);  
  }

  
  
  /** 
   * Returns which helplines should be drawn
   * 
   * @return   0 = 25%, 1 = 25%/50%/75%, 2 = none
   */  
  public final int getShowHelpLines()
  {
   return (null != jComboBoxHelpLines ? jComboBoxHelpLines.getSelectedIndex() : -1);  
  }
  
  
  
  /** 
   * Returns whether grid lines should be drawn
   * 
   * @return   -1 in case of error, 0 if grid lines borders should be drawn, 1 otherwise
   */  
  public final int getShowGridLines()
  {
   return (null != jComboBoxGridLines ? jComboBoxGridLines.getSelectedIndex() : -1);  
  }
  
  
  
  /** 
   * Returns whether the mouse wheel should be inverted
   * 
   * @return   -1 in case of error, 0 if the mouse wheel should be inverted, 1 otherwise
   */  
  public final int getInvertMouseWheel()
  {
   return (null != jComboBoxInvertWheel ? jComboBoxInvertWheel.getSelectedIndex() : -1);  
  }
  
  
  
  /** 
   * Returns the value of the given spinner
   * 
   * @return   spinner value
   */  
  private int getSpinnerValue(javax.swing.JSpinner pa_tSpinner)
  {
   if (null != pa_tSpinner)
   {
    return ((Integer) pa_tSpinner.getValue()).intValue();
   }
   return -1;    
  }
  
  
  
  /**
   * Returns the background color
   * 
   * @return background color
   */
  public final java.awt.Color getColorBg() {return jTextFieldColorBg.getBackground();}
  

  
  /**
   * Returns the cell border color
   * 
   * @return cell border color
   */
  public final java.awt.Color getColorCellBorders() {return jTextFieldColorCellBorders.getBackground();}
  
  
  
  /**
   * Returns the cell insertion frame color
   * 
   * @return cell insertion frame color
   */
  public final java.awt.Color getColorCellInsertionFrame() {return jTextFieldColorInsertionFrame.getBackground();}
  
  
  
  /**
   * Returns the cell selection frame color
   * 
   * @return cell selection frame color
   */
  public final java.awt.Color getColorCellSelectionFrame() {return jTextFieldColorSelectionFrame.getBackground();}
  
  
  
  /**
   * Returns the cell selection area color
   * 
   * @return cell selection area color
   */
  public final java.awt.Color getColorCellSelectionArea() {return jTextFieldColorSelectionArea.getBackground();}
  
  
  
  /**
   * Returns the cell insertion area color
   * 
   * @return cell insertion area color
   */
  public final java.awt.Color getColorCellInsertionArea() {return jTextFieldColorInsertionArea.getBackground();}
        
        
    
  /**
   * Returns the cell hilight color
   * 
   * @return cell hilight color
   */
  public final java.awt.Color getColorCellHilightLines() {return jTextFieldColorCellHiliteLines.getBackground();}
  
  
  
  /**
   * Returns the grid line color
   * 
   * @return grid line color
   */
  public final java.awt.Color getColorGridLines() {return jTextFieldColorGridLines.getBackground();}
  
  
  
  /**
   * Returns the help line color
   * 
   * @return help line color
   */
  public final java.awt.Color getColorHelpLines() {return jTextFieldColorHelpLines.getBackground();}
  

  
  /**
   * Sets the background color to the given value
   * 
   * @param pa_tColor   new background color
   */
  public final void setColorBg(java.awt.Color pa_tColor) {if (null != pa_tColor)  jTextFieldColorBg.setBackground(pa_tColor);}
  
  
  
  /**
   * Sets the cell border color to the given value
   * 
   * @param pa_tColor   new cell border color
   */
  public final void setColorCellBorders(java.awt.Color pa_tColor) {if (null != pa_tColor)  jTextFieldColorCellBorders.setBackground(pa_tColor);}

  
  
  /**
   * Sets the cell selection frame color to the given value
   * 
   * @param pa_tColor   new cell selection frame color
   */
  public final void setColorCellSelectionFrame(java.awt.Color pa_tColor) {if (null != pa_tColor)  jTextFieldColorSelectionFrame.setBackground(pa_tColor);}

  
  
  /**
   * Sets the cell selection area color to the given value
   * 
   * @param pa_tColor   new cell selection area color
   */
  public final void setColorCellSelectionArea(java.awt.Color pa_tColor) {if (null != pa_tColor)  jTextFieldColorSelectionArea.setBackground(pa_tColor);}

  
  
  /**
   * Sets the cell insertion area color to the given value
   * 
   * @param pa_tColor   new cell insertion area color
   */
  public final void setColorCellInsertionArea(java.awt.Color pa_tColor) {if (null != pa_tColor)  jTextFieldColorInsertionArea.setBackground(pa_tColor);}

  
  
  /**
   * Sets the cell insertion frame color to the given value
   * 
   * @param pa_tColor   new cell insertionf rame color
   */
  public final void setColorCellInsertionFrame(java.awt.Color pa_tColor) {if (null != pa_tColor)  jTextFieldColorInsertionFrame.setBackground(pa_tColor);}

  
  
  /**
   * Sets the cell higlight color to the given value
   * 
   * @param pa_tColor   new cell hilight color
   */
  public final void setColorCellHilightLines(java.awt.Color pa_tColor) {if (null != pa_tColor)  jTextFieldColorCellHiliteLines.setBackground(pa_tColor);}
  
  
  
  /**
   * Sets the grid lines color to the given value
   * 
   * @param pa_tColor   new grid lines color
   */
  public final void setColorGridLines(java.awt.Color pa_tColor) {if (null != pa_tColor)  jTextFieldColorGridLines.setBackground(pa_tColor);}
  
  
  
  /**
   * Sets the help lines color to the given value
   * 
   * @param pa_tColor   new help lines color
   */
  public final void setColorHelpLines(java.awt.Color pa_tColor) {if (null != pa_tColor)  jTextFieldColorHelpLines.setBackground(pa_tColor);}

  
  
  /** 
   * Returns the amount of columns
   * 
   * @return   amount of columns
   */
  public final int getColumns()
  {
   return getSpinnerValue(jSpinnerColumns);
  }
  
  
  
  /** 
   * Returns the amount of rows
   * 
   * @return   amount of rows
   */
  public final int getRows()
  {
   return getSpinnerValue(jSpinnerRows);
  }
  
  
  
  /**
   * Returns the animation delay
   * 
   * @return animation delay
   */
  public final int getDelay()
  {
   return getSpinnerValue(jSpinnerDelay);
  }
  
  
  
  /**
   * Returns the screenshot pixel size
   * 
   * @return screenshot pixel size
   */
  public final int getScreenshotCellSize()
  {
   return getSpinnerValue(jSpinnerScreenshotPixelSize);
  }
  
  
  
  /**
   * Returns he topology type
   * 
   * @return -1 in case of error, 0 = Moore, 1 = Von Neumann
   */
  public final int getTopology()
  {
   return (null != jComboBoxTopology ? jComboBoxTopology.getSelectedIndex() : -1);
  }
  
  
  
  /**
   * Returns an array of int representing the rule settings for a cell to stay alive
   * 
   * @return  int array
   */
  public final int[] getRulesStayAlive()
  {
   int[] lc_iResult = null;
   int   lc_iSize   = 1 + ((getNeighbourhood() == GridLifeConstants.GOL_NEIGHBOURHOOD_MOORE) ? 8 : 4); // increased by 1 since we also want a value for 0!

   if (null != (lc_iResult = new int[lc_iSize]))   
   {
    lc_iResult[0] = (true == jToggleButtonStayAlive0.isSelected() ? 1 : 0); 
    lc_iResult[1] = (true == jToggleButtonStayAlive1.isSelected() ? 1 : 0); 
    lc_iResult[2] = (true == jToggleButtonStayAlive2.isSelected() ? 1 : 0); 
    lc_iResult[3] = (true == jToggleButtonStayAlive3.isSelected() ? 1 : 0); 
    lc_iResult[4] = (true == jToggleButtonStayAlive4.isSelected() ? 1 : 0); 
    
    if (9 == lc_iSize)
    {
     lc_iResult[5] = (true == jToggleButtonStayAlive5.isSelected() ? 1 : 0); 
     lc_iResult[6] = (true == jToggleButtonStayAlive6.isSelected() ? 1 : 0); 
     lc_iResult[7] = (true == jToggleButtonStayAlive7.isSelected() ? 1 : 0); 
     lc_iResult[8] = (true == jToggleButtonStayAlive8.isSelected() ? 1 : 0);  
    }
   }
   return lc_iResult;
  }
  
  
  
  /**
   * Returns an array of int representing the rule settings for a cell to stay alive
   * 
   * @return  int array
   */
  public final int[] getRulesBecomeAlive()
  {
   int[] lc_iResult = null;
   int   lc_iSize   = 1 + ((getNeighbourhood() == GridLifeConstants.GOL_NEIGHBOURHOOD_MOORE) ? 8 : 4); // increased by 1 since we also want a value for 0!

   if (null != (lc_iResult = new int[lc_iSize]))   
   {
    lc_iResult[0] = (true == jToggleButtonBecomeAlive0.isSelected() ? 1 : 0); 
    lc_iResult[1] = (true == jToggleButtonBecomeAlive1.isSelected() ? 1 : 0); 
    lc_iResult[2] = (true == jToggleButtonBecomeAlive2.isSelected() ? 1 : 0); 
    lc_iResult[3] = (true == jToggleButtonBecomeAlive3.isSelected() ? 1 : 0); 
    lc_iResult[4] = (true == jToggleButtonBecomeAlive4.isSelected() ? 1 : 0); 
    
    if (9 == lc_iSize)
    {
     lc_iResult[5] = (true == jToggleButtonBecomeAlive5.isSelected() ? 1 : 0); 
     lc_iResult[6] = (true == jToggleButtonBecomeAlive6.isSelected() ? 1 : 0); 
     lc_iResult[7] = (true == jToggleButtonBecomeAlive7.isSelected() ? 1 : 0); 
     lc_iResult[8] = (true == jToggleButtonBecomeAlive8.isSelected() ? 1 : 0);  
    }
   }
   return lc_iResult;
  }

  
  
  /**
   * Enables or disables rulebuttons 5-8 according to the given neighbourhood value
   * 
   * @param pa_bValue  true, if all buttons should be available, false otherwise
   */
  public final void checkRuleButtons(boolean pa_bValue)
  {
   boolean lc_bNewValue = (false == pa_bValue ? pa_bValue : (getNeighbourhood() == GridLifeConstants.GOL_NEIGHBOURHOOD_MOORE ? true : false));
   
   //
   // disabling buttons 5-8 is always allowed, enabling only if we have a moore neighbourhood
   //
   jToggleButtonStayAlive5.setEnabled(lc_bNewValue);
   jToggleButtonStayAlive6.setEnabled(lc_bNewValue);
   jToggleButtonStayAlive7.setEnabled(lc_bNewValue);
   jToggleButtonStayAlive8.setEnabled(lc_bNewValue);
   jToggleButtonBecomeAlive5.setEnabled(lc_bNewValue);
   jToggleButtonBecomeAlive6.setEnabled(lc_bNewValue);
   jToggleButtonBecomeAlive7.setEnabled(lc_bNewValue);
   jToggleButtonBecomeAlive8.setEnabled(lc_bNewValue);           
  }
  
  
  
  /**
   * Sets the given properties
   * 
   * @param pa_tProperties  new properties
   */
  public final void setProperties(GridLifeProperties pa_tProperties)
  {
   int   lc_iNtype            = 0   ;   
   int[] lc_iStayAliveRules   = null;
   int[] lc_iBecomeAliveRules = null;
   
   if (null != pa_tProperties) 
   {
    jSpinnerColumns.setValue            (new Integer(pa_tProperties.getColumns())            );
    jSpinnerRows.setValue               (new Integer(pa_tProperties.getRows())               );
    jSpinnerDelay.setValue              (new Integer(pa_tProperties.getAnimationDelay())     );
    jSpinnerScreenshotPixelSize.setValue(new Integer(pa_tProperties.getScreenshotCellSize()));
    
    jComboBoxHelpLines.setSelectedIndex      (pa_tProperties.getShowHelpLines()      );
    jComboBoxGridLines.setSelectedIndex      (pa_tProperties.getShowGridLines()      );
    jComboBoxTopology.setSelectedIndex       (pa_tProperties.getTopology()           );
    jComboBoxNeighbourhood.setSelectedIndex  (pa_tProperties.getNeighbourHood()      );
    jComboBoxCellHiliteLines.setSelectedIndex(pa_tProperties.getShowCellHiliteLines());
    jComboBoxCellBorders.setSelectedIndex    (pa_tProperties.getShowCellBorders()    );
    jComboBoxInvertWheel.setSelectedIndex    (pa_tProperties.getInvertMouseWheel()   );
    
    jTextFieldColorBg.setBackground             (pa_tProperties.getColorBg()                );
    jTextFieldColorCellHiliteLines.setBackground(pa_tProperties.getColorCellHilightLines()  );
    jTextFieldColorGridLines.setBackground      (pa_tProperties.getColorGridLines()         );
    jTextFieldColorHelpLines.setBackground      (pa_tProperties.getColorHelpLines()         );
    jTextFieldColorCellBorders.setBackground    (pa_tProperties.getColorCellBorders()       );
    jTextFieldColorSelectionFrame.setBackground (pa_tProperties.getColorCellSelectionFrame());
    jTextFieldColorSelectionArea.setBackground  (pa_tProperties.getColorCellSelectionArea() );
    jTextFieldColorInsertionFrame.setBackground (pa_tProperties.getColorCellInsertionFrame());
    jTextFieldColorInsertionArea.setBackground  (pa_tProperties.getColorCellInsertionArea() );
    
    lc_iStayAliveRules   = pa_tProperties.getStayAliveRules();
    lc_iBecomeAliveRules = pa_tProperties.getBecomeAliveRules();
    lc_iNtype            = pa_tProperties.getNeighbourHood();
    
    //
    // select buttons according to rules
    //
    if (null != lc_iStayAliveRules && lc_iStayAliveRules.length >= 5)
    {
     jToggleButtonStayAlive0.setSelected(lc_iStayAliveRules[0] == 1);
     jToggleButtonStayAlive1.setSelected(lc_iStayAliveRules[1] == 1);
     jToggleButtonStayAlive2.setSelected(lc_iStayAliveRules[2] == 1);
     jToggleButtonStayAlive3.setSelected(lc_iStayAliveRules[3] == 1);
     jToggleButtonStayAlive4.setSelected(lc_iStayAliveRules[4] == 1);
    
     if (lc_iNtype == GridLifeConstants.GOL_NEIGHBOURHOOD_MOORE && lc_iStayAliveRules.length == 9)
     {
      jToggleButtonStayAlive5.setSelected(lc_iStayAliveRules[5] == 1);
      jToggleButtonStayAlive6.setSelected(lc_iStayAliveRules[6] == 1);
      jToggleButtonStayAlive7.setSelected(lc_iStayAliveRules[7] == 1);
      jToggleButtonStayAlive8.setSelected(lc_iStayAliveRules[8] == 1);
     }
    }
    
    if (null != lc_iBecomeAliveRules && lc_iBecomeAliveRules.length >= 5)
    {
     jToggleButtonBecomeAlive0.setSelected(lc_iBecomeAliveRules[0] == 1);
     jToggleButtonBecomeAlive1.setSelected(lc_iBecomeAliveRules[1] == 1);
     jToggleButtonBecomeAlive2.setSelected(lc_iBecomeAliveRules[2] == 1);
     jToggleButtonBecomeAlive3.setSelected(lc_iBecomeAliveRules[3] == 1);
     jToggleButtonBecomeAlive4.setSelected(lc_iBecomeAliveRules[4] == 1);
    
     if (lc_iNtype == GridLifeConstants.GOL_NEIGHBOURHOOD_MOORE && lc_iBecomeAliveRules.length == 9)
     {
      jToggleButtonBecomeAlive5.setSelected(lc_iBecomeAliveRules[5] == 1);
      jToggleButtonBecomeAlive6.setSelected(lc_iBecomeAliveRules[6] == 1);
      jToggleButtonBecomeAlive7.setSelected(lc_iBecomeAliveRules[7] == 1);
      jToggleButtonBecomeAlive8.setSelected(lc_iBecomeAliveRules[8] == 1);
     }
    }    
   }
  }
  
  
  /**
   * Enables or disables all relevant buttons
   * 
   * @param pa_bValue  true, if buttons should be enabled, false otherwise
   */
  public final void setWindowEnabled(boolean pa_bValue)
  {
   jSpinnerColumns.setEnabled            (pa_bValue);
   jSpinnerDelay.setEnabled              (pa_bValue);
   jSpinnerRows.setEnabled               (pa_bValue);
   jSpinnerScreenshotPixelSize.setEnabled(pa_bValue);
   
   jButtonApply.setEnabled               (pa_bValue);
   jButtonRestore.setEnabled             (pa_bValue);
   jButtonColorBg.setEnabled             (pa_bValue);
   jButtonColorCellHiliteLines.setEnabled(pa_bValue);
   jButtonColorGridLines.setEnabled      (pa_bValue);
   jButtonColorHelpLines.setEnabled      (pa_bValue);
   jButtonColorCellBorders.setEnabled    (pa_bValue);
   jButtonColorSelectionArea.setEnabled  (pa_bValue);
   jButtonColorInsertionArea.setEnabled  (pa_bValue);
   jButtonColorSelectionFrame.setEnabled (pa_bValue);           
   jButtonColorInsertionFrame.setEnabled (pa_bValue);           
   jButtonSave.setEnabled              (pa_bValue);
   jButtonLoad.setEnabled                (pa_bValue);
   
   jComboBoxHelpLines.setEnabled      (pa_bValue);
   jComboBoxTopology.setEnabled       (pa_bValue);
   jComboBoxNeighbourhood.setEnabled  (pa_bValue);
   jComboBoxGridLines.setEnabled      (pa_bValue);
   jComboBoxCellHiliteLines.setEnabled(pa_bValue);
   jComboBoxCellBorders.setEnabled    (pa_bValue);
   jComboBoxInvertWheel.setEnabled    (pa_bValue);
   
   jToggleButtonStayAlive0.setEnabled(pa_bValue);
   jToggleButtonStayAlive1.setEnabled(pa_bValue);
   jToggleButtonStayAlive2.setEnabled(pa_bValue);
   jToggleButtonStayAlive3.setEnabled(pa_bValue);
   jToggleButtonStayAlive4.setEnabled(pa_bValue);

   jToggleButtonBecomeAlive0.setEnabled(pa_bValue);
   jToggleButtonBecomeAlive1.setEnabled(pa_bValue);
   jToggleButtonBecomeAlive2.setEnabled(pa_bValue);
   jToggleButtonBecomeAlive3.setEnabled(pa_bValue);
   jToggleButtonBecomeAlive4.setEnabled(pa_bValue);
      
   checkRuleButtons(pa_bValue);
  }
  
  
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {
        java.awt.GridBagConstraints gridBagConstraints;

        jTabbedPaneProperties = new javax.swing.JTabbedPane();
        jPanelRuleset = new javax.swing.JPanel();
        jLabelStayAlive = new javax.swing.JLabel();
        jToggleButtonStayAlive0 = new javax.swing.JToggleButton();
        jToggleButtonStayAlive1 = new javax.swing.JToggleButton();
        jToggleButtonStayAlive2 = new javax.swing.JToggleButton();
        jToggleButtonStayAlive3 = new javax.swing.JToggleButton();
        jToggleButtonStayAlive4 = new javax.swing.JToggleButton();
        jToggleButtonStayAlive5 = new javax.swing.JToggleButton();
        jToggleButtonStayAlive6 = new javax.swing.JToggleButton();
        jToggleButtonStayAlive7 = new javax.swing.JToggleButton();
        jToggleButtonStayAlive8 = new javax.swing.JToggleButton();
        jLabelBecomeAlive = new javax.swing.JLabel();
        jToggleButtonBecomeAlive0 = new javax.swing.JToggleButton();
        jToggleButtonBecomeAlive1 = new javax.swing.JToggleButton();
        jToggleButtonBecomeAlive2 = new javax.swing.JToggleButton();
        jToggleButtonBecomeAlive3 = new javax.swing.JToggleButton();
        jToggleButtonBecomeAlive4 = new javax.swing.JToggleButton();
        jToggleButtonBecomeAlive5 = new javax.swing.JToggleButton();
        jToggleButtonBecomeAlive6 = new javax.swing.JToggleButton();
        jToggleButtonBecomeAlive7 = new javax.swing.JToggleButton();
        jToggleButtonBecomeAlive8 = new javax.swing.JToggleButton();
        jPanelMatrix = new javax.swing.JPanel();
        jLabelNeighbourhood = new javax.swing.JLabel();
        jLabelColumns = new javax.swing.JLabel();
        jLabelRows = new javax.swing.JLabel();
        jSpinnerRows = new javax.swing.JSpinner();
        jSpinnerColumns = new javax.swing.JSpinner();
        jLabelTopology = new javax.swing.JLabel();
        jComboBoxTopology = new javax.swing.JComboBox();
        jComboBoxNeighbourhood = new javax.swing.JComboBox();
        jPanelTools = new javax.swing.JPanel();
        jLabelAnimationDelay = new javax.swing.JLabel();
        jSpinnerDelay = new javax.swing.JSpinner();
        jLabelHelpLines = new javax.swing.JLabel();
        jComboBoxHelpLines = new javax.swing.JComboBox();
        jLabelGridLines = new javax.swing.JLabel();
        jComboBoxGridLines = new javax.swing.JComboBox();
        jLabelCellHiliteLines = new javax.swing.JLabel();
        jComboBoxCellHiliteLines = new javax.swing.JComboBox();
        jLabelCellBorders = new javax.swing.JLabel();
        jComboBoxCellBorders = new javax.swing.JComboBox();
        filler1 = new javax.swing.Box.Filler(new java.awt.Dimension(50, 10), new java.awt.Dimension(50, 10), new java.awt.Dimension(50, 10));
        jLabelScreenshotCellSize = new javax.swing.JLabel();
        jSpinnerScreenshotPixelSize = new javax.swing.JSpinner();
        jLabelInvertWheel = new javax.swing.JLabel();
        jComboBoxInvertWheel = new javax.swing.JComboBox();
        jPanelToolColors = new javax.swing.JPanel();
        jButtonColorHelpLines = new javax.swing.JButton();
        jButtonColorGridLines = new javax.swing.JButton();
        jButtonColorCellHiliteLines = new javax.swing.JButton();
        jButtonColorCellBorders = new javax.swing.JButton();
        jButtonColorBg = new javax.swing.JButton();
        jTextFieldColorHelpLines = new javax.swing.JTextField();
        jTextFieldColorGridLines = new javax.swing.JTextField();
        jTextFieldColorCellHiliteLines = new javax.swing.JTextField();
        jTextFieldColorCellBorders = new javax.swing.JTextField();
        jTextFieldColorBg = new javax.swing.JTextField();
        jButtonColorSelectionFrame = new javax.swing.JButton();
        jButtonColorSelectionArea = new javax.swing.JButton();
        jTextFieldColorSelectionFrame = new javax.swing.JTextField();
        jTextFieldColorSelectionArea = new javax.swing.JTextField();
        jButtonColorInsertionArea = new javax.swing.JButton();
        jTextFieldColorInsertionArea = new javax.swing.JTextField();
        jButtonColorInsertionFrame = new javax.swing.JButton();
        jTextFieldColorInsertionFrame = new javax.swing.JTextField();
        jPanelButtons = new javax.swing.JPanel();
        jButtonApply = new javax.swing.JButton();
        jButtonRestore = new javax.swing.JButton();
        jButtonLoad = new javax.swing.JButton();
        jButtonSave = new javax.swing.JButton();
        filler2 = new javax.swing.Box.Filler(new java.awt.Dimension(0, 0), new java.awt.Dimension(0, 0), new java.awt.Dimension(32767, 0));

        setClosable(true);
        setDefaultCloseOperation(javax.swing.WindowConstants.DO_NOTHING_ON_CLOSE);
        setIconifiable(true);
        setResizable(true);
        java.util.ResourceBundle bundle = java.util.ResourceBundle.getBundle("gridlife/ui/resources/GridLifePropertiesWindow"); // NOI18N
        setTitle(bundle.getString("Form.title")); // NOI18N
        setAlignmentX(1.0F);
        setAlignmentY(1.0F);
        setDoubleBuffered(true);
        setName("Form"); // NOI18N
        setPreferredSize(new java.awt.Dimension(600, 220));
        getContentPane().setLayout(new java.awt.GridBagLayout());

        jTabbedPaneProperties.setTabLayoutPolicy(javax.swing.JTabbedPane.SCROLL_TAB_LAYOUT);
        jTabbedPaneProperties.setAlignmentX(0.0F);
        jTabbedPaneProperties.setAlignmentY(0.0F);
        jTabbedPaneProperties.setName("jTabbedPaneProperties"); // NOI18N
        jTabbedPaneProperties.setPreferredSize(new java.awt.Dimension(575, 220));

        jPanelRuleset.setAlignmentX(1.0F);
        jPanelRuleset.setAlignmentY(1.0F);
        jPanelRuleset.setName("jPanelRuleset"); // NOI18N
        jPanelRuleset.setPreferredSize(new java.awt.Dimension(490, 171));

        jLabelStayAlive.setLabelFor(jLabelStayAlive);
        jLabelStayAlive.setText(bundle.getString("jLabelStayAlive.text")); // NOI18N
        jLabelStayAlive.setName("jLabelStayAlive"); // NOI18N

        jToggleButtonStayAlive0.setText(bundle.getString("jToggleButtonStayAlive0.text")); // NOI18N
        jToggleButtonStayAlive0.setActionCommand(bundle.getString("jToggleButtonStayAlive0.actionCommand")); // NOI18N
        jToggleButtonStayAlive0.setName("jToggleButtonStayAlive0"); // NOI18N
        jToggleButtonStayAlive0.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonStayAlive1.setText(bundle.getString("jToggleButtonStayAlive1.text")); // NOI18N
        jToggleButtonStayAlive1.setActionCommand(bundle.getString("jToggleButtonStayAlive1.actionCommand")); // NOI18N
        jToggleButtonStayAlive1.setName("jToggleButtonStayAlive1"); // NOI18N
        jToggleButtonStayAlive1.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonStayAlive2.setSelected(true);
        jToggleButtonStayAlive2.setText(bundle.getString("jToggleButtonStayAlive2.text")); // NOI18N
        jToggleButtonStayAlive2.setActionCommand(bundle.getString("jToggleButtonStayAlive2.actionCommand")); // NOI18N
        jToggleButtonStayAlive2.setName("jToggleButtonStayAlive2"); // NOI18N
        jToggleButtonStayAlive2.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonStayAlive3.setSelected(true);
        jToggleButtonStayAlive3.setText(bundle.getString("jToggleButtonStayAlive3.text")); // NOI18N
        jToggleButtonStayAlive3.setActionCommand(bundle.getString("jToggleButtonStayAlive3.actionCommand")); // NOI18N
        jToggleButtonStayAlive3.setName("jToggleButtonStayAlive3"); // NOI18N
        jToggleButtonStayAlive3.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonStayAlive4.setText(bundle.getString("jToggleButtonStayAlive4.text")); // NOI18N
        jToggleButtonStayAlive4.setActionCommand(bundle.getString("jToggleButtonStayAlive4.actionCommand")); // NOI18N
        jToggleButtonStayAlive4.setName("jToggleButtonStayAlive4"); // NOI18N
        jToggleButtonStayAlive4.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonStayAlive5.setText(bundle.getString("jToggleButtonStayAlive5.text")); // NOI18N
        jToggleButtonStayAlive5.setActionCommand(bundle.getString("jToggleButtonStayAlive5.actionCommand")); // NOI18N
        jToggleButtonStayAlive5.setName("jToggleButtonStayAlive5"); // NOI18N
        jToggleButtonStayAlive5.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonStayAlive6.setText(bundle.getString("jToggleButtonStayAlive6.text")); // NOI18N
        jToggleButtonStayAlive6.setActionCommand(bundle.getString("jToggleButtonStayAlive6.actionCommand")); // NOI18N
        jToggleButtonStayAlive6.setName("jToggleButtonStayAlive6"); // NOI18N
        jToggleButtonStayAlive6.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonStayAlive7.setText(bundle.getString("jToggleButtonStayAlive7.text")); // NOI18N
        jToggleButtonStayAlive7.setActionCommand(bundle.getString("jToggleButtonStayAlive7.actionCommand")); // NOI18N
        jToggleButtonStayAlive7.setName("jToggleButtonStayAlive7"); // NOI18N
        jToggleButtonStayAlive7.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonStayAlive8.setText(bundle.getString("jToggleButtonStayAlive8.text")); // NOI18N
        jToggleButtonStayAlive8.setActionCommand(bundle.getString("jToggleButtonStayAlive8.actionCommand")); // NOI18N
        jToggleButtonStayAlive8.setName("jToggleButtonStayAlive8"); // NOI18N
        jToggleButtonStayAlive8.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jLabelBecomeAlive.setLabelFor(jLabelStayAlive);
        jLabelBecomeAlive.setText(bundle.getString("jLabelBecomeAlive.text")); // NOI18N
        jLabelBecomeAlive.setName("jLabelBecomeAlive"); // NOI18N

        jToggleButtonBecomeAlive0.setText(bundle.getString("jToggleButtonBecomeAlive0.text")); // NOI18N
        jToggleButtonBecomeAlive0.setActionCommand(bundle.getString("jToggleButtonBecomeAlive0.actionCommand")); // NOI18N
        jToggleButtonBecomeAlive0.setName("jToggleButtonBecomeAlive0"); // NOI18N
        jToggleButtonBecomeAlive0.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonBecomeAlive1.setText(bundle.getString("jToggleButtonBecomeAlive1.text")); // NOI18N
        jToggleButtonBecomeAlive1.setActionCommand(bundle.getString("jToggleButtonBecomeAlive1.actionCommand")); // NOI18N
        jToggleButtonBecomeAlive1.setName("jToggleButtonBecomeAlive1"); // NOI18N
        jToggleButtonBecomeAlive1.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonBecomeAlive2.setText(bundle.getString("jToggleButtonBecomeAlive2.text")); // NOI18N
        jToggleButtonBecomeAlive2.setActionCommand(bundle.getString("jToggleButtonBecomeAlive2.actionCommand")); // NOI18N
        jToggleButtonBecomeAlive2.setName("jToggleButtonBecomeAlive2"); // NOI18N
        jToggleButtonBecomeAlive2.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonBecomeAlive3.setSelected(true);
        jToggleButtonBecomeAlive3.setText(bundle.getString("jToggleButtonBecomeAlive3.text")); // NOI18N
        jToggleButtonBecomeAlive3.setActionCommand(bundle.getString("jToggleButtonBecomeAlive3.actionCommand")); // NOI18N
        jToggleButtonBecomeAlive3.setName("jToggleButtonBecomeAlive3"); // NOI18N
        jToggleButtonBecomeAlive3.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonBecomeAlive4.setText(bundle.getString("jToggleButtonBecomeAlive4.text")); // NOI18N
        jToggleButtonBecomeAlive4.setActionCommand(bundle.getString("jToggleButtonBecomeAlive4.actionCommand")); // NOI18N
        jToggleButtonBecomeAlive4.setName("jToggleButtonBecomeAlive4"); // NOI18N
        jToggleButtonBecomeAlive4.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonBecomeAlive5.setText(bundle.getString("jToggleButtonBecomeAlive5.text")); // NOI18N
        jToggleButtonBecomeAlive5.setActionCommand(bundle.getString("jToggleButtonBecomeAlive5.actionCommand")); // NOI18N
        jToggleButtonBecomeAlive5.setName("jToggleButtonBecomeAlive5"); // NOI18N
        jToggleButtonBecomeAlive5.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonBecomeAlive6.setText(bundle.getString("jToggleButtonBecomeAlive6.text")); // NOI18N
        jToggleButtonBecomeAlive6.setActionCommand(bundle.getString("jToggleButtonBecomeAlive6.actionCommand")); // NOI18N
        jToggleButtonBecomeAlive6.setName("jToggleButtonBecomeAlive6"); // NOI18N
        jToggleButtonBecomeAlive6.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonBecomeAlive7.setText(bundle.getString("jToggleButtonBecomeAlive7.text")); // NOI18N
        jToggleButtonBecomeAlive7.setActionCommand(bundle.getString("jToggleButtonBecomeAlive7.actionCommand")); // NOI18N
        jToggleButtonBecomeAlive7.setName("jToggleButtonBecomeAlive7"); // NOI18N
        jToggleButtonBecomeAlive7.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        jToggleButtonBecomeAlive8.setText(bundle.getString("jToggleButtonBecomeAlive8.text")); // NOI18N
        jToggleButtonBecomeAlive8.setActionCommand(bundle.getString("jToggleButtonBecomeAlive8.actionCommand")); // NOI18N
        jToggleButtonBecomeAlive8.setName("jToggleButtonBecomeAlive8"); // NOI18N
        jToggleButtonBecomeAlive8.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                stateChangedToggleButton_PR(evt);
            }
        });

        javax.swing.GroupLayout jPanelRulesetLayout = new javax.swing.GroupLayout(jPanelRuleset);
        jPanelRuleset.setLayout(jPanelRulesetLayout);
        jPanelRulesetLayout.setHorizontalGroup(
            jPanelRulesetLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanelRulesetLayout.createSequentialGroup()
                .addGroup(jPanelRulesetLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(jPanelRulesetLayout.createSequentialGroup()
                        .addGap(10, 10, 10)
                        .addGroup(jPanelRulesetLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(jLabelBecomeAlive)
                            .addComponent(jLabelStayAlive)))
                    .addGroup(jPanelRulesetLayout.createSequentialGroup()
                        .addContainerGap()
                        .addGroup(jPanelRulesetLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addGroup(jPanelRulesetLayout.createSequentialGroup()
                                .addComponent(jToggleButtonStayAlive0)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonStayAlive1)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonStayAlive2)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonStayAlive3)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonStayAlive4)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonStayAlive5)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonStayAlive6)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonStayAlive7)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonStayAlive8))
                            .addGroup(jPanelRulesetLayout.createSequentialGroup()
                                .addComponent(jToggleButtonBecomeAlive0)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonBecomeAlive1)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonBecomeAlive2)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonBecomeAlive3)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonBecomeAlive4)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonBecomeAlive5)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonBecomeAlive6)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonBecomeAlive7)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addComponent(jToggleButtonBecomeAlive8)))))
                .addContainerGap(161, Short.MAX_VALUE))
        );

        jPanelRulesetLayout.linkSize(javax.swing.SwingConstants.HORIZONTAL, new java.awt.Component[] {jLabelBecomeAlive, jLabelStayAlive});

        jPanelRulesetLayout.linkSize(javax.swing.SwingConstants.HORIZONTAL, new java.awt.Component[] {jToggleButtonBecomeAlive0, jToggleButtonBecomeAlive1, jToggleButtonBecomeAlive2, jToggleButtonBecomeAlive3, jToggleButtonBecomeAlive4, jToggleButtonBecomeAlive5, jToggleButtonBecomeAlive6, jToggleButtonBecomeAlive7, jToggleButtonBecomeAlive8, jToggleButtonStayAlive0, jToggleButtonStayAlive1, jToggleButtonStayAlive2, jToggleButtonStayAlive3, jToggleButtonStayAlive4, jToggleButtonStayAlive5, jToggleButtonStayAlive6, jToggleButtonStayAlive7, jToggleButtonStayAlive8});

        jPanelRulesetLayout.setVerticalGroup(
            jPanelRulesetLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanelRulesetLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jLabelStayAlive)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanelRulesetLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jToggleButtonStayAlive0)
                    .addComponent(jToggleButtonStayAlive1)
                    .addComponent(jToggleButtonStayAlive2)
                    .addComponent(jToggleButtonStayAlive3)
                    .addComponent(jToggleButtonStayAlive4)
                    .addComponent(jToggleButtonStayAlive5)
                    .addComponent(jToggleButtonStayAlive6)
                    .addComponent(jToggleButtonStayAlive7)
                    .addComponent(jToggleButtonStayAlive8))
                .addGap(18, 18, 18)
                .addComponent(jLabelBecomeAlive)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanelRulesetLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jToggleButtonBecomeAlive0)
                    .addComponent(jToggleButtonBecomeAlive1)
                    .addComponent(jToggleButtonBecomeAlive2)
                    .addComponent(jToggleButtonBecomeAlive3)
                    .addComponent(jToggleButtonBecomeAlive4)
                    .addComponent(jToggleButtonBecomeAlive5)
                    .addComponent(jToggleButtonBecomeAlive6)
                    .addComponent(jToggleButtonBecomeAlive7)
                    .addComponent(jToggleButtonBecomeAlive8))
                .addContainerGap(28, Short.MAX_VALUE))
        );

        jPanelRulesetLayout.linkSize(javax.swing.SwingConstants.VERTICAL, new java.awt.Component[] {jLabelBecomeAlive, jLabelStayAlive, jToggleButtonBecomeAlive0, jToggleButtonBecomeAlive1, jToggleButtonBecomeAlive2, jToggleButtonBecomeAlive3, jToggleButtonBecomeAlive4, jToggleButtonBecomeAlive5, jToggleButtonBecomeAlive6, jToggleButtonBecomeAlive7, jToggleButtonBecomeAlive8, jToggleButtonStayAlive0, jToggleButtonStayAlive1, jToggleButtonStayAlive2, jToggleButtonStayAlive3, jToggleButtonStayAlive4, jToggleButtonStayAlive5, jToggleButtonStayAlive6, jToggleButtonStayAlive7, jToggleButtonStayAlive8});

        jTabbedPaneProperties.addTab(bundle.getString("jPanelRuleset.TabConstraints.tabTitle"), jPanelRuleset); // NOI18N

        jPanelMatrix.setAlignmentX(1.0F);
        jPanelMatrix.setAlignmentY(1.0F);
        jPanelMatrix.setName("jPanelMatrix"); // NOI18N
        jPanelMatrix.setPreferredSize(new java.awt.Dimension(490, 171));

        jLabelNeighbourhood.setText(bundle.getString("jLabelNeighbourhood.text")); // NOI18N
        jLabelNeighbourhood.setName("jLabelNeighbourhood"); // NOI18N

        jLabelColumns.setLabelFor(jSpinnerColumns);
        jLabelColumns.setText(bundle.getString("jLabelColumns.text")); // NOI18N
        jLabelColumns.setName("jLabelColumns"); // NOI18N

        jLabelRows.setLabelFor(jSpinnerRows);
        jLabelRows.setText(bundle.getString("jLabelRows.text")); // NOI18N
        jLabelRows.setName("jLabelRows"); // NOI18N

        jSpinnerRows.setModel(new javax.swing.SpinnerNumberModel(150, 20, 5000, 1));
        jSpinnerRows.setName("jSpinnerRows"); // NOI18N
        jSpinnerRows.setValue(new Integer(160));
        jSpinnerRows.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                stateChangedSpinner_PR_Rows(evt);
            }
        });

        jSpinnerColumns.setModel(new javax.swing.SpinnerNumberModel(150, 20, 5000, 1));
        jSpinnerColumns.setName("jSpinnerColumns"); // NOI18N
        jSpinnerColumns.setValue(new Integer(160));
        jSpinnerColumns.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                stateChangedSpinner_PR_Columns(evt);
            }
        });

        jLabelTopology.setText(bundle.getString("jLabelTopology.text")); // NOI18N
        jLabelTopology.setName("jLabelTopology"); // NOI18N

        jComboBoxTopology.setModel(new javax.swing.DefaultComboBoxModel(new String[] { bundle.getString("jSpinnerTopology.itemSheet.text"), bundle.getString("jSpinnerTopology.itemTorus.text") }));
        jComboBoxTopology.setSelectedItem(bundle.getString("jSpinnerTopology.itemTorus.text"));
        jComboBoxTopology.setName("jComboBoxTopology"); // NOI18N
        jComboBoxTopology.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedCombobox_PR_Topology(evt);
            }
        });

        jComboBoxNeighbourhood.setModel(new javax.swing.DefaultComboBoxModel(new String[] { bundle.getString("jSpinnerNeighbourhood.itemMoore.text"), bundle.getString("jSpinnerNeighbourhood.itemVonNeumann.text") }));
        jComboBoxNeighbourhood.setSelectedItem(bundle.getString("jSpinnerNeighbourhood.itemMoore.text"));
        jComboBoxNeighbourhood.setName("jComboBoxNeighbourhood"); // NOI18N
        jComboBoxNeighbourhood.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedCombobox_PR_Neighbourhood(evt);
            }
        });

        javax.swing.GroupLayout jPanelMatrixLayout = new javax.swing.GroupLayout(jPanelMatrix);
        jPanelMatrix.setLayout(jPanelMatrixLayout);
        jPanelMatrixLayout.setHorizontalGroup(
            jPanelMatrixLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanelMatrixLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanelMatrixLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(jPanelMatrixLayout.createSequentialGroup()
                        .addComponent(jLabelTopology, javax.swing.GroupLayout.DEFAULT_SIZE, 73, Short.MAX_VALUE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jComboBoxTopology, 0, 99, Short.MAX_VALUE))
                    .addGroup(jPanelMatrixLayout.createSequentialGroup()
                        .addComponent(jLabelNeighbourhood, javax.swing.GroupLayout.DEFAULT_SIZE, 73, Short.MAX_VALUE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jComboBoxNeighbourhood, 0, 99, Short.MAX_VALUE)
                        .addGap(18, 18, 18)))
                .addGap(18, 18, 18)
                .addGroup(jPanelMatrixLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(jLabelRows, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(jLabelColumns, javax.swing.GroupLayout.DEFAULT_SIZE, 45, Short.MAX_VALUE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanelMatrixLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jSpinnerColumns, javax.swing.GroupLayout.DEFAULT_SIZE, 87, Short.MAX_VALUE)
                    .addComponent(jSpinnerRows, javax.swing.GroupLayout.DEFAULT_SIZE, 87, Short.MAX_VALUE))
                .addGap(446, 446, 446))
        );

        jPanelMatrixLayout.linkSize(javax.swing.SwingConstants.HORIZONTAL, new java.awt.Component[] {jComboBoxNeighbourhood, jComboBoxTopology});

        jPanelMatrixLayout.linkSize(javax.swing.SwingConstants.HORIZONTAL, new java.awt.Component[] {jSpinnerColumns, jSpinnerRows});

        jPanelMatrixLayout.linkSize(javax.swing.SwingConstants.HORIZONTAL, new java.awt.Component[] {jLabelNeighbourhood, jLabelTopology});

        jPanelMatrixLayout.setVerticalGroup(
            jPanelMatrixLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanelMatrixLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanelMatrixLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addGroup(jPanelMatrixLayout.createSequentialGroup()
                        .addComponent(jSpinnerColumns, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jSpinnerRows, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addGroup(jPanelMatrixLayout.createSequentialGroup()
                        .addGroup(jPanelMatrixLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jComboBoxTopology, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jLabelTopology)
                            .addComponent(jLabelColumns, javax.swing.GroupLayout.DEFAULT_SIZE, 20, Short.MAX_VALUE))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(jPanelMatrixLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jLabelNeighbourhood)
                            .addComponent(jComboBoxNeighbourhood, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jLabelRows))))
                .addGap(286, 286, 286))
        );

        jPanelMatrixLayout.linkSize(javax.swing.SwingConstants.VERTICAL, new java.awt.Component[] {jComboBoxNeighbourhood, jComboBoxTopology, jLabelColumns, jLabelNeighbourhood, jLabelRows, jLabelTopology, jSpinnerColumns, jSpinnerRows});

        jTabbedPaneProperties.addTab(bundle.getString("jPanelMatrix.TabConstraints.tabTitle"), jPanelMatrix); // NOI18N

        jPanelTools.setAlignmentX(1.0F);
        jPanelTools.setAlignmentY(1.0F);
        jPanelTools.setName("jPanelTools"); // NOI18N
        jPanelTools.setPreferredSize(new java.awt.Dimension(490, 171));

        jLabelAnimationDelay.setLabelFor(jSpinnerDelay);
        jLabelAnimationDelay.setText(bundle.getString("jLabelAnimationDelay.text")); // NOI18N
        jLabelAnimationDelay.setMaximumSize(new java.awt.Dimension(105, 20));
        jLabelAnimationDelay.setMinimumSize(new java.awt.Dimension(105, 20));
        jLabelAnimationDelay.setName("jLabelAnimationDelay"); // NOI18N
        jLabelAnimationDelay.setPreferredSize(new java.awt.Dimension(105, 20));

        jSpinnerDelay.setModel(new javax.swing.SpinnerNumberModel(125, 1, 2500, 1));
        jSpinnerDelay.setMaximumSize(new java.awt.Dimension(50, 20));
        jSpinnerDelay.setMinimumSize(new java.awt.Dimension(50, 20));
        jSpinnerDelay.setName("jSpinnerDelay"); // NOI18N
        jSpinnerDelay.setPreferredSize(new java.awt.Dimension(50, 20));
        jSpinnerDelay.setValue(new Integer(125));
        jSpinnerDelay.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                stateChangedSpinner_PR_Delay(evt);
            }
        });

        jLabelHelpLines.setLabelFor(jComboBoxHelpLines);
        jLabelHelpLines.setText(bundle.getString("jLabelHelpLines.text")); // NOI18N
        jLabelHelpLines.setMaximumSize(new java.awt.Dimension(105, 20));
        jLabelHelpLines.setMinimumSize(new java.awt.Dimension(105, 20));
        jLabelHelpLines.setName("jLabelHelpLines"); // NOI18N
        jLabelHelpLines.setPreferredSize(new java.awt.Dimension(105, 20));

        jComboBoxHelpLines.setModel(new javax.swing.DefaultComboBoxModel(new String[] { bundle.getString("jSpinnerDisplayHelpLines.item0.text"), bundle.getString("jSpinnerDisplayHelpLines.item50.text"), bundle.getString("jSpinnerDisplayHelpLines.item100.text") }));
        jComboBoxHelpLines.setSelectedItem(bundle.getString("jSpinnerDisplayHelpLines.item0.text"));
        jComboBoxHelpLines.setName("jComboBoxHelpLines"); // NOI18N
        jComboBoxHelpLines.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                handleCombobox_PR_HelpLines(evt);
            }
        });

        jLabelGridLines.setLabelFor(jComboBoxHelpLines);
        jLabelGridLines.setText(bundle.getString("jLabelGridLines.text")); // NOI18N
        jLabelGridLines.setMaximumSize(new java.awt.Dimension(105, 20));
        jLabelGridLines.setMinimumSize(new java.awt.Dimension(105, 20));
        jLabelGridLines.setName("jLabelGridLines"); // NOI18N
        jLabelGridLines.setPreferredSize(new java.awt.Dimension(105, 20));

        jComboBoxGridLines.setModel(new javax.swing.DefaultComboBoxModel(new String[] { bundle.getString("jSpinner.itemOff.text"), bundle.getString("jSpinner.itemOn.text") }));
        jComboBoxGridLines.setSelectedItem(bundle.getString("jSpinner.itemOff.text"));
        jComboBoxGridLines.setName("jComboBoxGridLines"); // NOI18N
        jComboBoxGridLines.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                handleCombobox_PR_GridLines(evt);
            }
        });

        jLabelCellHiliteLines.setLabelFor(jComboBoxCellHiliteLines);
        jLabelCellHiliteLines.setText(bundle.getString("jLabelCellHiliteLines.text")); // NOI18N
        jLabelCellHiliteLines.setMaximumSize(new java.awt.Dimension(105, 20));
        jLabelCellHiliteLines.setMinimumSize(new java.awt.Dimension(105, 20));
        jLabelCellHiliteLines.setName("jLabelCellHiliteLines"); // NOI18N
        jLabelCellHiliteLines.setPreferredSize(new java.awt.Dimension(105, 20));

        jComboBoxCellHiliteLines.setModel(new javax.swing.DefaultComboBoxModel(new String[] { bundle.getString("jSpinner.itemOff.text"), bundle.getString("jSpinner.itemOn.text") }));
        jComboBoxCellHiliteLines.setSelectedItem(bundle.getString("jSpinner.itemOff.text"));
        jComboBoxCellHiliteLines.setName("jComboBoxCellHiliteLines"); // NOI18N
        jComboBoxCellHiliteLines.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                handleCombobox_PR_CellHiliteLines(evt);
            }
        });

        jLabelCellBorders.setLabelFor(jComboBoxCellHiliteLines);
        jLabelCellBorders.setText(bundle.getString("jLabelCellBorders.text")); // NOI18N
        jLabelCellBorders.setMaximumSize(new java.awt.Dimension(105, 20));
        jLabelCellBorders.setMinimumSize(new java.awt.Dimension(105, 20));
        jLabelCellBorders.setName("jLabelCellBorders"); // NOI18N
        jLabelCellBorders.setPreferredSize(new java.awt.Dimension(105, 20));

        jComboBoxCellBorders.setModel(new javax.swing.DefaultComboBoxModel(new String[] { bundle.getString("jSpinner.itemOff.text"), bundle.getString("jSpinner.itemOn.text") }));
        jComboBoxCellBorders.setSelectedItem(bundle.getString("jSpinner.itemOff.text"));
        jComboBoxCellBorders.setName("jComboBoxCellBorders"); // NOI18N
        jComboBoxCellBorders.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                handleCombobox_PR_CellBorder(evt);
            }
        });

        filler1.setAlignmentX(1.0F);
        filler1.setAlignmentY(0.0F);
        filler1.setAutoscrolls(true);
        filler1.setName("filler1"); // NOI18N

        jLabelScreenshotCellSize.setLabelFor(jSpinnerScreenshotPixelSize);
        jLabelScreenshotCellSize.setText(bundle.getString("jLabelScreenshotCellSize.text")); // NOI18N
        jLabelScreenshotCellSize.setMaximumSize(new java.awt.Dimension(105, 20));
        jLabelScreenshotCellSize.setMinimumSize(new java.awt.Dimension(105, 20));
        jLabelScreenshotCellSize.setName("jLabelScreenshotCellSize"); // NOI18N
        jLabelScreenshotCellSize.setPreferredSize(new java.awt.Dimension(105, 20));

        jSpinnerScreenshotPixelSize.setModel(new javax.swing.SpinnerNumberModel(3, 1, 150, 1));
        jSpinnerScreenshotPixelSize.setMaximumSize(new java.awt.Dimension(50, 20));
        jSpinnerScreenshotPixelSize.setMinimumSize(new java.awt.Dimension(50, 20));
        jSpinnerScreenshotPixelSize.setName("jSpinnerScreenshotPixelSize"); // NOI18N
        jSpinnerScreenshotPixelSize.setPreferredSize(new java.awt.Dimension(50, 20));
        jSpinnerScreenshotPixelSize.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                stateChangedSpinner_PR_ScreenshotPixelSize(evt);
            }
        });

        jLabelInvertWheel.setLabelFor(jComboBoxInvertWheel);
        jLabelInvertWheel.setText(bundle.getString("jLabelInvertWheel.text")); // NOI18N
        jLabelInvertWheel.setMaximumSize(new java.awt.Dimension(105, 20));
        jLabelInvertWheel.setMinimumSize(new java.awt.Dimension(105, 20));
        jLabelInvertWheel.setName("jLabelInvertWheel"); // NOI18N
        jLabelInvertWheel.setPreferredSize(new java.awt.Dimension(105, 20));

        jComboBoxInvertWheel.setModel(new javax.swing.DefaultComboBoxModel(new String[] { bundle.getString("jSpinner.itemOff.text"), bundle.getString("jSpinner.itemOn.text") }));
        jComboBoxInvertWheel.setSelectedItem(bundle.getString("jSpinner.itemOff.text"));
        jComboBoxInvertWheel.setName("jComboBoxInvertWheel"); // NOI18N
        jComboBoxInvertWheel.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                handleCombobox_PR_InvertWheel(evt);
            }
        });

        javax.swing.GroupLayout jPanelToolsLayout = new javax.swing.GroupLayout(jPanelTools);
        jPanelTools.setLayout(jPanelToolsLayout);
        jPanelToolsLayout.setHorizontalGroup(
            jPanelToolsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanelToolsLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanelToolsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(jPanelToolsLayout.createSequentialGroup()
                        .addComponent(jLabelHelpLines, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jComboBoxHelpLines, 0, 105, Short.MAX_VALUE))
                    .addGroup(jPanelToolsLayout.createSequentialGroup()
                        .addComponent(jLabelGridLines, javax.swing.GroupLayout.DEFAULT_SIZE, 125, Short.MAX_VALUE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jComboBoxGridLines, 0, 105, Short.MAX_VALUE))
                    .addGroup(jPanelToolsLayout.createSequentialGroup()
                        .addComponent(jLabelCellHiliteLines, javax.swing.GroupLayout.DEFAULT_SIZE, 125, Short.MAX_VALUE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jComboBoxCellHiliteLines, 0, 105, Short.MAX_VALUE))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanelToolsLayout.createSequentialGroup()
                        .addGroup(jPanelToolsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(jLabelCellBorders, javax.swing.GroupLayout.DEFAULT_SIZE, 125, Short.MAX_VALUE)
                            .addComponent(jLabelInvertWheel, javax.swing.GroupLayout.PREFERRED_SIZE, 125, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(jPanelToolsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(jComboBoxInvertWheel, 0, 105, Short.MAX_VALUE)
                            .addComponent(jComboBoxCellBorders, 0, 105, Short.MAX_VALUE))))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(filler1, javax.swing.GroupLayout.PREFERRED_SIZE, 50, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanelToolsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(jLabelScreenshotCellSize, javax.swing.GroupLayout.DEFAULT_SIZE, 125, Short.MAX_VALUE)
                    .addComponent(jLabelAnimationDelay, javax.swing.GroupLayout.DEFAULT_SIZE, 125, Short.MAX_VALUE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addGroup(jPanelToolsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(jSpinnerScreenshotPixelSize, javax.swing.GroupLayout.PREFERRED_SIZE, 105, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jSpinnerDelay, javax.swing.GroupLayout.PREFERRED_SIZE, 105, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addContainerGap())
        );

        jPanelToolsLayout.linkSize(javax.swing.SwingConstants.HORIZONTAL, new java.awt.Component[] {jLabelAnimationDelay, jLabelCellBorders, jLabelCellHiliteLines, jLabelGridLines, jLabelHelpLines, jLabelInvertWheel, jLabelScreenshotCellSize});

        jPanelToolsLayout.linkSize(javax.swing.SwingConstants.HORIZONTAL, new java.awt.Component[] {jComboBoxCellBorders, jComboBoxCellHiliteLines, jComboBoxGridLines, jComboBoxHelpLines, jComboBoxInvertWheel, jSpinnerDelay, jSpinnerScreenshotPixelSize});

        jPanelToolsLayout.setVerticalGroup(
            jPanelToolsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanelToolsLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanelToolsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
                    .addComponent(filler1, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addGroup(javax.swing.GroupLayout.Alignment.LEADING, jPanelToolsLayout.createSequentialGroup()
                        .addGroup(jPanelToolsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jLabelHelpLines, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jComboBoxHelpLines, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jLabelAnimationDelay, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jSpinnerDelay, javax.swing.GroupLayout.PREFERRED_SIZE, 20, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(jPanelToolsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jLabelGridLines, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jComboBoxGridLines, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jLabelScreenshotCellSize, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jSpinnerScreenshotPixelSize, javax.swing.GroupLayout.PREFERRED_SIZE, 20, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(jPanelToolsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jLabelCellHiliteLines, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jComboBoxCellHiliteLines, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(jPanelToolsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jLabelCellBorders, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jComboBoxCellBorders, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(jPanelToolsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jLabelInvertWheel, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jComboBoxInvertWheel, javax.swing.GroupLayout.PREFERRED_SIZE, 20, javax.swing.GroupLayout.PREFERRED_SIZE))))
                .addContainerGap(26, Short.MAX_VALUE))
        );

        jPanelToolsLayout.linkSize(javax.swing.SwingConstants.VERTICAL, new java.awt.Component[] {jComboBoxCellBorders, jComboBoxCellHiliteLines, jComboBoxGridLines, jComboBoxHelpLines, jComboBoxInvertWheel, jLabelAnimationDelay, jLabelCellBorders, jLabelCellHiliteLines, jLabelGridLines, jLabelHelpLines, jLabelInvertWheel, jLabelScreenshotCellSize, jSpinnerDelay, jSpinnerScreenshotPixelSize});

        jTabbedPaneProperties.addTab(bundle.getString("jPanelTools.TabConstraints.tabTitle"), jPanelTools); // NOI18N

        jPanelToolColors.setAlignmentX(1.0F);
        jPanelToolColors.setAlignmentY(1.0F);
        jPanelToolColors.setName("jPanelToolColors"); // NOI18N
        jPanelToolColors.setPreferredSize(new java.awt.Dimension(490, 171));

        jButtonColorHelpLines.setText(bundle.getString("jButtonColorHelpLines.text")); // NOI18N
        jButtonColorHelpLines.setActionCommand(bundle.getString("jButtonColorHelpLines.actionCommand")); // NOI18N
        jButtonColorHelpLines.setName("jButtonColorHelpLines"); // NOI18N
        jButtonColorHelpLines.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedButton_PR_ColorHelplines(evt);
            }
        });

        jButtonColorGridLines.setText(bundle.getString("jButtonColorGridLines.text")); // NOI18N
        jButtonColorGridLines.setActionCommand(bundle.getString("jButtonColorGridLines.actionCommand")); // NOI18N
        jButtonColorGridLines.setName("jButtonColorGridLines"); // NOI18N
        jButtonColorGridLines.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedButton_PR_ColorGridlines(evt);
            }
        });

        jButtonColorCellHiliteLines.setText(bundle.getString("jButtonColorCellHiliteLines.text")); // NOI18N
        jButtonColorCellHiliteLines.setActionCommand(bundle.getString("jButtonColorCellHiliteLines.actionCommand")); // NOI18N
        jButtonColorCellHiliteLines.setName("jButtonColorCellHiliteLines"); // NOI18N
        jButtonColorCellHiliteLines.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedButton_PR_ColorCellHiliteLines(evt);
            }
        });

        jButtonColorCellBorders.setText(bundle.getString("jButtonColorCellBorders.text")); // NOI18N
        jButtonColorCellBorders.setActionCommand(bundle.getString("jButtonColorCellBorders.actionCommand")); // NOI18N
        jButtonColorCellBorders.setName("jButtonColorCellBorders"); // NOI18N
        jButtonColorCellBorders.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedButton_PR_ColorCellBorders(evt);
            }
        });

        jButtonColorBg.setText(bundle.getString("jButtonColorBg.text")); // NOI18N
        jButtonColorBg.setActionCommand(bundle.getString("jButtonColorBg.actionCommand")); // NOI18N
        jButtonColorBg.setName("jButtonColorBg"); // NOI18N
        jButtonColorBg.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedButton_PR_ColorBg(evt);
            }
        });

        org.jdesktop.application.ResourceMap resourceMap = org.jdesktop.application.Application.getInstance(gridlife.core.GridLifeApp.class).getContext().getResourceMap(GridLifePropertiesWindow.class);
        jTextFieldColorHelpLines.setBackground(resourceMap.getColor("jTextFieldColorHelpLines.background")); // NOI18N
        jTextFieldColorHelpLines.setEditable(false);
        jTextFieldColorHelpLines.setText(bundle.getString("jTextFieldColorHelpLines.text")); // NOI18N
        jTextFieldColorHelpLines.setName("jTextFieldColorHelpLines"); // NOI18N

        jTextFieldColorGridLines.setEditable(false);
        jTextFieldColorGridLines.setText(bundle.getString("jTextFieldColorGridLines.text")); // NOI18N
        jTextFieldColorGridLines.setName("jTextFieldColorGridLines"); // NOI18N

        jTextFieldColorCellHiliteLines.setBackground(resourceMap.getColor("jTextFieldColorCellHiliteLines.background")); // NOI18N
        jTextFieldColorCellHiliteLines.setEditable(false);
        jTextFieldColorCellHiliteLines.setText(bundle.getString("jTextFieldColorCellHiliteLines.text")); // NOI18N
        jTextFieldColorCellHiliteLines.setName("jTextFieldColorCellHiliteLines"); // NOI18N

        jTextFieldColorCellBorders.setBackground(resourceMap.getColor("jTextFieldColorCellBorders.background")); // NOI18N
        jTextFieldColorCellBorders.setEditable(false);
        jTextFieldColorCellBorders.setText(bundle.getString("jTextFieldColorCellBorders.text")); // NOI18N
        jTextFieldColorCellBorders.setName("jTextFieldColorCellBorders"); // NOI18N

        jTextFieldColorBg.setBackground(resourceMap.getColor("jTextFieldColorBg.background")); // NOI18N
        jTextFieldColorBg.setEditable(false);
        jTextFieldColorBg.setText(bundle.getString("jTextFieldColorBg.text")); // NOI18N
        jTextFieldColorBg.setName("jTextFieldColorBg"); // NOI18N

        jButtonColorSelectionFrame.setText(bundle.getString("jButtonColorSelectionFrame.text")); // NOI18N
        jButtonColorSelectionFrame.setActionCommand(bundle.getString("jButtonColorSelectionFrame.actionCommand")); // NOI18N
        jButtonColorSelectionFrame.setName("jButtonColorSelectionFrame"); // NOI18N
        jButtonColorSelectionFrame.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedButton_PR_ColorSelectionFrame(evt);
            }
        });

        jButtonColorSelectionArea.setText(bundle.getString("jButtonColorSelectionArea.text")); // NOI18N
        jButtonColorSelectionArea.setActionCommand(bundle.getString("jButtonColorSelectionArea.actionCommand")); // NOI18N
        jButtonColorSelectionArea.setName("jButtonColorSelectionArea"); // NOI18N
        jButtonColorSelectionArea.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedButton_PR_ColorSelectionArea(evt);
            }
        });

        jTextFieldColorSelectionFrame.setBackground(resourceMap.getColor("jTextFieldColorSelectionFrame.background")); // NOI18N
        jTextFieldColorSelectionFrame.setEditable(false);
        jTextFieldColorSelectionFrame.setText(bundle.getString("jTextFieldColorSelectionFrame.text")); // NOI18N
        jTextFieldColorSelectionFrame.setName("jTextFieldColorSelectionFrame"); // NOI18N

        jTextFieldColorSelectionArea.setBackground(resourceMap.getColor("jTextFieldColorSelectionArea.background")); // NOI18N
        jTextFieldColorSelectionArea.setEditable(false);
        jTextFieldColorSelectionArea.setText(bundle.getString("jTextFieldColorSelectionArea.text")); // NOI18N
        jTextFieldColorSelectionArea.setName("jTextFieldColorSelectionArea"); // NOI18N

        jButtonColorInsertionArea.setText(bundle.getString("jButtonColorInsertionArea.text")); // NOI18N
        jButtonColorInsertionArea.setActionCommand(bundle.getString("jButtonColorInsertionArea.actionCommand")); // NOI18N
        jButtonColorInsertionArea.setName("jButtonColorInsertionArea"); // NOI18N
        jButtonColorInsertionArea.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedButton_PR_ColorInsertionArea(evt);
            }
        });

        jTextFieldColorInsertionArea.setBackground(resourceMap.getColor("jTextFieldColorInsertionArea.background")); // NOI18N
        jTextFieldColorInsertionArea.setEditable(false);
        jTextFieldColorInsertionArea.setText(bundle.getString("jTextFieldColorInsertionArea.text")); // NOI18N
        jTextFieldColorInsertionArea.setName("jTextFieldColorInsertionArea"); // NOI18N

        jButtonColorInsertionFrame.setText(bundle.getString("jButtonColorInsertionFrame.text")); // NOI18N
        jButtonColorInsertionFrame.setActionCommand(bundle.getString("jButtonColorInsertionFrame.actionCommand")); // NOI18N
        jButtonColorInsertionFrame.setName("jButtonColorInsertionFrame"); // NOI18N
        jButtonColorInsertionFrame.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedButton_PR_ColorInsertionFrame(evt);
            }
        });

        jTextFieldColorInsertionFrame.setBackground(resourceMap.getColor("jTextFieldColorInsertionFrame.background")); // NOI18N
        jTextFieldColorInsertionFrame.setEditable(false);
        jTextFieldColorInsertionFrame.setText(bundle.getString("jTextFieldColorInsertionFrame.text")); // NOI18N
        jTextFieldColorInsertionFrame.setName("jTextFieldColorInsertionFrame"); // NOI18N

        javax.swing.GroupLayout jPanelToolColorsLayout = new javax.swing.GroupLayout(jPanelToolColors);
        jPanelToolColors.setLayout(jPanelToolColorsLayout);
        jPanelToolColorsLayout.setHorizontalGroup(
            jPanelToolColorsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanelToolColorsLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanelToolColorsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(jPanelToolColorsLayout.createSequentialGroup()
                        .addComponent(jButtonColorBg, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jTextFieldColorBg, javax.swing.GroupLayout.DEFAULT_SIZE, 87, Short.MAX_VALUE))
                    .addGroup(jPanelToolColorsLayout.createSequentialGroup()
                        .addComponent(jButtonColorCellBorders, javax.swing.GroupLayout.DEFAULT_SIZE, 101, Short.MAX_VALUE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jTextFieldColorCellBorders, javax.swing.GroupLayout.DEFAULT_SIZE, 87, Short.MAX_VALUE))
                    .addGroup(jPanelToolColorsLayout.createSequentialGroup()
                        .addComponent(jButtonColorCellHiliteLines, javax.swing.GroupLayout.DEFAULT_SIZE, 101, Short.MAX_VALUE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jTextFieldColorCellHiliteLines, javax.swing.GroupLayout.DEFAULT_SIZE, 87, Short.MAX_VALUE))
                    .addGroup(jPanelToolColorsLayout.createSequentialGroup()
                        .addComponent(jButtonColorGridLines, javax.swing.GroupLayout.DEFAULT_SIZE, 101, Short.MAX_VALUE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jTextFieldColorGridLines, javax.swing.GroupLayout.PREFERRED_SIZE, 87, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addGroup(jPanelToolColorsLayout.createSequentialGroup()
                        .addComponent(jButtonColorHelpLines, javax.swing.GroupLayout.DEFAULT_SIZE, 101, Short.MAX_VALUE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jTextFieldColorHelpLines, javax.swing.GroupLayout.PREFERRED_SIZE, 87, javax.swing.GroupLayout.PREFERRED_SIZE)))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addGroup(jPanelToolColorsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jButtonColorInsertionArea, javax.swing.GroupLayout.DEFAULT_SIZE, 130, Short.MAX_VALUE)
                    .addComponent(jButtonColorSelectionFrame, javax.swing.GroupLayout.PREFERRED_SIZE, 130, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jButtonColorSelectionArea, javax.swing.GroupLayout.DEFAULT_SIZE, 130, Short.MAX_VALUE)
                    .addComponent(jButtonColorInsertionFrame, javax.swing.GroupLayout.DEFAULT_SIZE, 130, Short.MAX_VALUE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanelToolColorsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jTextFieldColorInsertionArea, javax.swing.GroupLayout.PREFERRED_SIZE, 87, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jTextFieldColorSelectionFrame, javax.swing.GroupLayout.PREFERRED_SIZE, 87, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jTextFieldColorSelectionArea, javax.swing.GroupLayout.PREFERRED_SIZE, 87, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jTextFieldColorInsertionFrame, javax.swing.GroupLayout.PREFERRED_SIZE, 87, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(367, 367, 367))
        );

        jPanelToolColorsLayout.linkSize(javax.swing.SwingConstants.HORIZONTAL, new java.awt.Component[] {jButtonColorBg, jButtonColorCellBorders, jButtonColorCellHiliteLines, jButtonColorGridLines, jButtonColorHelpLines});

        jPanelToolColorsLayout.linkSize(javax.swing.SwingConstants.HORIZONTAL, new java.awt.Component[] {jButtonColorInsertionArea, jButtonColorInsertionFrame, jButtonColorSelectionArea, jButtonColorSelectionFrame});

        jPanelToolColorsLayout.linkSize(javax.swing.SwingConstants.HORIZONTAL, new java.awt.Component[] {jTextFieldColorBg, jTextFieldColorCellBorders, jTextFieldColorCellHiliteLines, jTextFieldColorGridLines, jTextFieldColorHelpLines, jTextFieldColorInsertionArea, jTextFieldColorInsertionFrame, jTextFieldColorSelectionArea, jTextFieldColorSelectionFrame});

        jPanelToolColorsLayout.setVerticalGroup(
            jPanelToolColorsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanelToolColorsLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanelToolColorsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addGroup(jPanelToolColorsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                        .addGroup(jPanelToolColorsLayout.createSequentialGroup()
                            .addComponent(jTextFieldColorSelectionFrame, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                            .addComponent(jTextFieldColorSelectionArea, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                            .addGroup(jPanelToolColorsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                                .addGroup(javax.swing.GroupLayout.Alignment.LEADING, jPanelToolColorsLayout.createSequentialGroup()
                                    .addGap(29, 29, 29)
                                    .addComponent(jTextFieldColorInsertionArea, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                                .addComponent(jTextFieldColorInsertionFrame, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)))
                        .addGroup(jPanelToolColorsLayout.createSequentialGroup()
                            .addComponent(jButtonColorSelectionFrame)
                            .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                            .addComponent(jButtonColorSelectionArea)
                            .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                            .addGroup(jPanelToolColorsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                                .addGroup(javax.swing.GroupLayout.Alignment.LEADING, jPanelToolColorsLayout.createSequentialGroup()
                                    .addGap(29, 29, 29)
                                    .addComponent(jButtonColorInsertionArea))
                                .addComponent(jButtonColorInsertionFrame, javax.swing.GroupLayout.Alignment.LEADING))))
                    .addGroup(jPanelToolColorsLayout.createSequentialGroup()
                        .addGroup(jPanelToolColorsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jButtonColorHelpLines)
                            .addComponent(jTextFieldColorHelpLines, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(jPanelToolColorsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jButtonColorGridLines)
                            .addComponent(jTextFieldColorGridLines, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(jPanelToolColorsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jButtonColorCellHiliteLines)
                            .addComponent(jTextFieldColorCellHiliteLines, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(jPanelToolColorsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jButtonColorCellBorders)
                            .addComponent(jTextFieldColorCellBorders, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanelToolColorsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jButtonColorBg)
                    .addComponent(jTextFieldColorBg, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        jPanelToolColorsLayout.linkSize(javax.swing.SwingConstants.VERTICAL, new java.awt.Component[] {jButtonColorBg, jButtonColorCellBorders, jButtonColorCellHiliteLines, jButtonColorGridLines, jButtonColorHelpLines, jButtonColorInsertionArea, jButtonColorInsertionFrame, jButtonColorSelectionArea, jButtonColorSelectionFrame, jTextFieldColorBg, jTextFieldColorCellBorders, jTextFieldColorCellHiliteLines, jTextFieldColorGridLines, jTextFieldColorHelpLines, jTextFieldColorInsertionArea, jTextFieldColorInsertionFrame, jTextFieldColorSelectionArea, jTextFieldColorSelectionFrame});

        jTabbedPaneProperties.addTab(bundle.getString("jPanelToolColors.TabConstraints.tabTitle"), jPanelToolColors); // NOI18N

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.ipadx = 16;
        gridBagConstraints.ipady = 5;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.weighty = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(11, 10, 0, 10);
        getContentPane().add(jTabbedPaneProperties, gridBagConstraints);
        jTabbedPaneProperties.getAccessibleContext().setAccessibleName(resourceMap.getString("jTabbedPane1.AccessibleContext.accessibleName")); // NOI18N

        jPanelButtons.setBorder(javax.swing.BorderFactory.createEtchedBorder());
        jPanelButtons.setAlignmentX(0.0F);
        jPanelButtons.setAlignmentY(0.0F);
        jPanelButtons.setName("jPanelButtons"); // NOI18N
        jPanelButtons.setLayout(new java.awt.GridBagLayout());

        jButtonApply.setIcon(resourceMap.getIcon("jButtonApply.icon")); // NOI18N
        jButtonApply.setText(bundle.getString("jButtonApply.text")); // NOI18N
        jButtonApply.setToolTipText(bundle.getString("jButtonApply.tooltipText")); // NOI18N
        jButtonApply.setActionCommand(bundle.getString("jButtonApply.actionCommand")); // NOI18N
        jButtonApply.setMaximumSize(new java.awt.Dimension(30, 30));
        jButtonApply.setMinimumSize(new java.awt.Dimension(30, 30));
        jButtonApply.setName("jButtonApply"); // NOI18N
        jButtonApply.setPreferredSize(new java.awt.Dimension(30, 30));
        jButtonApply.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedButton_PR_Apply(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(10, 10, 10, 0);
        jPanelButtons.add(jButtonApply, gridBagConstraints);

        jButtonRestore.setIcon(resourceMap.getIcon("jButtonRestore.icon")); // NOI18N
        jButtonRestore.setText(bundle.getString("jButtonRestore.text")); // NOI18N
        jButtonRestore.setToolTipText(bundle.getString("jButtonRestore.tooltipText")); // NOI18N
        jButtonRestore.setActionCommand(bundle.getString("jButtonRestore.actionCommand")); // NOI18N
        jButtonRestore.setMaximumSize(new java.awt.Dimension(30, 30));
        jButtonRestore.setMinimumSize(new java.awt.Dimension(30, 30));
        jButtonRestore.setName("jButtonRestore"); // NOI18N
        jButtonRestore.setPreferredSize(new java.awt.Dimension(30, 30));
        jButtonRestore.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedButton_PR_Reset(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(10, 5, 10, 0);
        jPanelButtons.add(jButtonRestore, gridBagConstraints);

        jButtonLoad.setIcon(resourceMap.getIcon("jButtonLoad.icon")); // NOI18N
        jButtonLoad.setText(bundle.getString("jButtonLoad.text")); // NOI18N
        jButtonLoad.setToolTipText(bundle.getString("jButtonLoad.tooltipText")); // NOI18N
        jButtonLoad.setActionCommand(bundle.getString("jButtonLoad.acrionCommand")); // NOI18N
        jButtonLoad.setFocusable(false);
        jButtonLoad.setMaximumSize(new java.awt.Dimension(30, 30));
        jButtonLoad.setMinimumSize(new java.awt.Dimension(30, 30));
        jButtonLoad.setName("jButtonLoad"); // NOI18N
        jButtonLoad.setPreferredSize(new java.awt.Dimension(30, 30));
        jButtonLoad.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedButton_PR_Load(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(10, 0, 10, 0);
        jPanelButtons.add(jButtonLoad, gridBagConstraints);

        jButtonSave.setIcon(resourceMap.getIcon("jButtonSave.icon")); // NOI18N
        jButtonSave.setText(bundle.getString("jButtonSave.text")); // NOI18N
        jButtonSave.setToolTipText(bundle.getString("jButtonSave.tooltipText")); // NOI18N
        jButtonSave.setActionCommand(bundle.getString("jButtonSave.actionCommand")); // NOI18N
        jButtonSave.setMaximumSize(new java.awt.Dimension(30, 30));
        jButtonSave.setMinimumSize(new java.awt.Dimension(30, 30));
        jButtonSave.setName("jButtonSave"); // NOI18N
        jButtonSave.setPreferredSize(new java.awt.Dimension(30, 30));
        jButtonSave.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedButton_PR_SaveAs(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 4;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(10, 5, 10, 10);
        jPanelButtons.add(jButtonSave, gridBagConstraints);

        filler2.setName("filler2"); // NOI18N
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.weightx = 1.0;
        jPanelButtons.add(filler2, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.ipadx = 421;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(6, 10, 11, 10);
        getContentPane().add(jPanelButtons, gridBagConstraints);

        pack();
    }// </editor-fold>//GEN-END:initComponents

  
/***************************************** getters for UI objects *****************************************************/
public final javax.swing.JButton getButtonApply()   {return jButtonApply;  }

public final javax.swing.JButton getButtonRestore() {return jButtonRestore;}

  

/********************************************* event handling methods ****************************************************/    
  private void actionPerformedButton_PR_Reset(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedButton_PR_Reset
    if (null != m_tGuiConnector) m_tGuiConnector.handleButton_PR_Reset();
  }//GEN-LAST:event_actionPerformedButton_PR_Reset

  private void actionPerformedButton_PR_Apply(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedButton_PR_Apply
    if (null != m_tGuiConnector) m_tGuiConnector.handleButton_PR_Apply();
  }//GEN-LAST:event_actionPerformedButton_PR_Apply

private void actionPerformedButton_PR_SaveAs(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedButton_PR_SaveAs
if (null != m_tGuiConnector) m_tGuiConnector.handleButton_PR_SaveAs();  
}//GEN-LAST:event_actionPerformedButton_PR_SaveAs

private void actionPerformedButton_PR_Load(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedButton_PR_Load
if (null != m_tGuiConnector) m_tGuiConnector.handleButton_PR_Load();  
}//GEN-LAST:event_actionPerformedButton_PR_Load

private void actionPerformedButton_PR_ColorSelectionArea(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedButton_PR_ColorSelectionArea
if (null != m_tGuiConnector) m_tGuiConnector.handleButton_PR_Color(6, getColorCellSelectionArea());  
}//GEN-LAST:event_actionPerformedButton_PR_ColorSelectionArea

private void actionPerformedButton_PR_ColorSelectionFrame(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedButton_PR_ColorSelectionFrame
if (null != m_tGuiConnector) m_tGuiConnector.handleButton_PR_Color(5, getColorCellSelectionFrame());  
}//GEN-LAST:event_actionPerformedButton_PR_ColorSelectionFrame

private void actionPerformedButton_PR_ColorBg(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedButton_PR_ColorBg
if (null != m_tGuiConnector) m_tGuiConnector.handleButton_PR_Color(0, getColorBg());
}//GEN-LAST:event_actionPerformedButton_PR_ColorBg

private void actionPerformedButton_PR_ColorCellBorders(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedButton_PR_ColorCellBorders
if (null != m_tGuiConnector) m_tGuiConnector.handleButton_PR_Color(4, getColorCellBorders());  
}//GEN-LAST:event_actionPerformedButton_PR_ColorCellBorders

private void actionPerformedButton_PR_ColorCellHiliteLines(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedButton_PR_ColorCellHiliteLines
if (null != m_tGuiConnector) m_tGuiConnector.handleButton_PR_Color(3, getColorCellHilightLines());  
}//GEN-LAST:event_actionPerformedButton_PR_ColorCellHiliteLines

private void actionPerformedButton_PR_ColorGridlines(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedButton_PR_ColorGridlines
if (null != m_tGuiConnector) m_tGuiConnector.handleButton_PR_Color(1, getColorGridLines());
}//GEN-LAST:event_actionPerformedButton_PR_ColorGridlines

private void actionPerformedButton_PR_ColorHelplines(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedButton_PR_ColorHelplines
if (null != m_tGuiConnector) m_tGuiConnector.handleButton_PR_Color(2, getColorHelpLines());  
}//GEN-LAST:event_actionPerformedButton_PR_ColorHelplines

private void handleCombobox_PR_CellBorder(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_handleCombobox_PR_CellBorder
if (null != m_tGuiConnector) m_tGuiConnector.handleCombobox_PR_CellBorder();
}//GEN-LAST:event_handleCombobox_PR_CellBorder

private void handleCombobox_PR_CellHiliteLines(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_handleCombobox_PR_CellHiliteLines
  if (null != m_tGuiConnector) m_tGuiConnector.handleCombobox_PR_CellHiliteLines();
}//GEN-LAST:event_handleCombobox_PR_CellHiliteLines

private void handleCombobox_PR_GridLines(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_handleCombobox_PR_GridLines
  if (null != m_tGuiConnector) m_tGuiConnector.handleCombobox_PR_GridLines();
}//GEN-LAST:event_handleCombobox_PR_GridLines

private void handleCombobox_PR_HelpLines(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_handleCombobox_PR_HelpLines
  if (null != m_tGuiConnector) m_tGuiConnector.handleCombobox_PR_ShowHelpLines();
}//GEN-LAST:event_handleCombobox_PR_HelpLines

private void stateChangedSpinner_PR_Delay(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_stateChangedSpinner_PR_Delay
    if (null != m_tGuiConnector) m_tGuiConnector.handleSpinner_PR_PropertyChanged();
}//GEN-LAST:event_stateChangedSpinner_PR_Delay

private void actionPerformedCombobox_PR_Neighbourhood(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedCombobox_PR_Neighbourhood
  if (null != m_tGuiConnector) m_tGuiConnector.handleCombobox_PR_Neighbourhood();
}//GEN-LAST:event_actionPerformedCombobox_PR_Neighbourhood

private void actionPerformedCombobox_PR_Topology(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedCombobox_PR_Topology
  if (null != m_tGuiConnector) m_tGuiConnector.handleCombobox_PR_Topology();
}//GEN-LAST:event_actionPerformedCombobox_PR_Topology

private void stateChangedSpinner_PR_Columns(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_stateChangedSpinner_PR_Columns
    if (null != m_tGuiConnector) m_tGuiConnector.handleSpinner_PR_PropertyChanged();
}//GEN-LAST:event_stateChangedSpinner_PR_Columns

private void stateChangedSpinner_PR_Rows(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_stateChangedSpinner_PR_Rows
    if (null != m_tGuiConnector) m_tGuiConnector.handleSpinner_PR_PropertyChanged();
}//GEN-LAST:event_stateChangedSpinner_PR_Rows

private void stateChangedToggleButton_PR(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_stateChangedToggleButton_PR
if (null != m_tGuiConnector) m_tGuiConnector.handleToggleButton_PR_Ruleset(evt);  
}//GEN-LAST:event_stateChangedToggleButton_PR

private void actionPerformedButton_PR_ColorInsertionArea(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedButton_PR_ColorInsertionArea
if (null != m_tGuiConnector) m_tGuiConnector.handleButton_PR_Color(7, getColorCellInsertionArea());    
}//GEN-LAST:event_actionPerformedButton_PR_ColorInsertionArea

private void actionPerformedButton_PR_ColorInsertionFrame(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedButton_PR_ColorInsertionFrame
if (null != m_tGuiConnector) m_tGuiConnector.handleButton_PR_Color(8, getColorCellInsertionFrame());    
}//GEN-LAST:event_actionPerformedButton_PR_ColorInsertionFrame

  private void stateChangedSpinner_PR_ScreenshotPixelSize(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_stateChangedSpinner_PR_ScreenshotPixelSize
    if (null != m_tGuiConnector) m_tGuiConnector.handleSpinner_PR_PropertyChanged();
  }//GEN-LAST:event_stateChangedSpinner_PR_ScreenshotPixelSize

  private void handleCombobox_PR_InvertWheel(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_handleCombobox_PR_InvertWheel
     if (null != m_tGuiConnector) m_tGuiConnector.handleCombobox_PR_InvertMouseWheel();
  }//GEN-LAST:event_handleCombobox_PR_InvertWheel


/**
 * Enables autocommit for the given spinner
 * 
 * @param pa_tSpinner    spinner
 */
private void setAutoCommit(javax.swing.JSpinner pa_tSpinner)
{
 javax.swing.text.DefaultFormatter  lc_tFormatter = null;
 javax.swing.JSpinner.NumberEditor  lc_tEditor    = null;
 
 if (null != pa_tSpinner)
 {
  if (null != pa_tSpinner.getEditor())
  {
   if (null != (lc_tEditor = (javax.swing.JSpinner.NumberEditor) pa_tSpinner.getEditor()))
   {
    if (null != lc_tEditor.getTextField()) 
    {
     if (null != lc_tEditor.getTextField().getFormatter())
     {
      if (null != (lc_tFormatter = (javax.swing.text.DefaultFormatter) lc_tEditor.getTextField().getFormatter()))
      {
       lc_tFormatter.setCommitsOnValidEdit(true);
      }
     }
    }
   }
  }
 }
}


    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.Box.Filler filler1;
    private javax.swing.Box.Filler filler2;
    private javax.swing.JButton jButtonApply;
    private javax.swing.JButton jButtonColorBg;
    private javax.swing.JButton jButtonColorCellBorders;
    private javax.swing.JButton jButtonColorCellHiliteLines;
    private javax.swing.JButton jButtonColorGridLines;
    private javax.swing.JButton jButtonColorHelpLines;
    private javax.swing.JButton jButtonColorInsertionArea;
    private javax.swing.JButton jButtonColorInsertionFrame;
    private javax.swing.JButton jButtonColorSelectionArea;
    private javax.swing.JButton jButtonColorSelectionFrame;
    private javax.swing.JButton jButtonLoad;
    private javax.swing.JButton jButtonRestore;
    private javax.swing.JButton jButtonSave;
    private javax.swing.JComboBox jComboBoxCellBorders;
    private javax.swing.JComboBox jComboBoxCellHiliteLines;
    private javax.swing.JComboBox jComboBoxGridLines;
    private javax.swing.JComboBox jComboBoxHelpLines;
    private javax.swing.JComboBox jComboBoxInvertWheel;
    private javax.swing.JComboBox jComboBoxNeighbourhood;
    private javax.swing.JComboBox jComboBoxTopology;
    private javax.swing.JLabel jLabelAnimationDelay;
    private javax.swing.JLabel jLabelBecomeAlive;
    private javax.swing.JLabel jLabelCellBorders;
    private javax.swing.JLabel jLabelCellHiliteLines;
    private javax.swing.JLabel jLabelColumns;
    private javax.swing.JLabel jLabelGridLines;
    private javax.swing.JLabel jLabelHelpLines;
    private javax.swing.JLabel jLabelInvertWheel;
    private javax.swing.JLabel jLabelNeighbourhood;
    private javax.swing.JLabel jLabelRows;
    private javax.swing.JLabel jLabelScreenshotCellSize;
    private javax.swing.JLabel jLabelStayAlive;
    private javax.swing.JLabel jLabelTopology;
    private javax.swing.JPanel jPanelButtons;
    private javax.swing.JPanel jPanelMatrix;
    private javax.swing.JPanel jPanelRuleset;
    private javax.swing.JPanel jPanelToolColors;
    private javax.swing.JPanel jPanelTools;
    private javax.swing.JSpinner jSpinnerColumns;
    private javax.swing.JSpinner jSpinnerDelay;
    private javax.swing.JSpinner jSpinnerRows;
    private javax.swing.JSpinner jSpinnerScreenshotPixelSize;
    private javax.swing.JTabbedPane jTabbedPaneProperties;
    private javax.swing.JTextField jTextFieldColorBg;
    private javax.swing.JTextField jTextFieldColorCellBorders;
    private javax.swing.JTextField jTextFieldColorCellHiliteLines;
    private javax.swing.JTextField jTextFieldColorGridLines;
    private javax.swing.JTextField jTextFieldColorHelpLines;
    private javax.swing.JTextField jTextFieldColorInsertionArea;
    private javax.swing.JTextField jTextFieldColorInsertionFrame;
    private javax.swing.JTextField jTextFieldColorSelectionArea;
    private javax.swing.JTextField jTextFieldColorSelectionFrame;
    private javax.swing.JToggleButton jToggleButtonBecomeAlive0;
    private javax.swing.JToggleButton jToggleButtonBecomeAlive1;
    private javax.swing.JToggleButton jToggleButtonBecomeAlive2;
    private javax.swing.JToggleButton jToggleButtonBecomeAlive3;
    private javax.swing.JToggleButton jToggleButtonBecomeAlive4;
    private javax.swing.JToggleButton jToggleButtonBecomeAlive5;
    private javax.swing.JToggleButton jToggleButtonBecomeAlive6;
    private javax.swing.JToggleButton jToggleButtonBecomeAlive7;
    private javax.swing.JToggleButton jToggleButtonBecomeAlive8;
    private javax.swing.JToggleButton jToggleButtonStayAlive0;
    private javax.swing.JToggleButton jToggleButtonStayAlive1;
    private javax.swing.JToggleButton jToggleButtonStayAlive2;
    private javax.swing.JToggleButton jToggleButtonStayAlive3;
    private javax.swing.JToggleButton jToggleButtonStayAlive4;
    private javax.swing.JToggleButton jToggleButtonStayAlive5;
    private javax.swing.JToggleButton jToggleButtonStayAlive6;
    private javax.swing.JToggleButton jToggleButtonStayAlive7;
    private javax.swing.JToggleButton jToggleButtonStayAlive8;
    // End of variables declaration//GEN-END:variables
}
