/*
 * GridLifeQuickSlotDialog.java
 *
 * Created on 04.11.2011, 15:46:07
 */
package gridlife.ui;



/**
 *
 * @author Ulf Wagemann
 */
public class GridLifeQuickSlotDialog extends javax.swing.JDialog 
{
 private GridLifeGuiConnector m_tGuiConnector;


 
  /**
  * Constructor
  * 
  * @param parent               parent frame
  * @param modal                modal flag
  * @param pa_tGuiConnector     guiconnector object
  */
  public GridLifeQuickSlotDialog(java.awt.Frame parent, boolean modal, GridLifeGuiConnector pa_tGuiConnector) 
  {
   super(parent, modal);
  
   m_tGuiConnector = pa_tGuiConnector;
   initComponents();
   
   jListSlots.setCellRenderer(new GridLifeQuickSlotListCellRenderer()); 
   jListSlots.setModel(new GridLifeListModel());
   jListSlots.setBackground(java.awt.Color.white);   
  }

  
  /**
   * Checks whether the list has a selection
   * 
   * @return   true, if the list has a selection, false otherwise
   */
  public final boolean hasListSelection() {return (-1 != jListSlots.getSelectedIndex());}
  

  
  /**
   * Checks whether the list has entries
   * 
   * @return   true, if the list has entries, false otherwise
   */
  public final boolean hasListEntries() {return (0 < jListSlots.getModel().getSize());}
  

  
    /**
   * Clears the list and adds the shapes to it
   * 
   * @param pa_tShapeSet   shapeset
   */
  public final void initList(String[] pa_tQuickSaveSlots, String pa_sSlot)
  {
   GridLifeListModel  lc_tListModel = (GridLifeListModel) jListSlots.getModel();
 
   int lc_iI      = 0;
   int lc_iLength = 0;
   int lc_iIndex  = -1;
   
   if (null != lc_tListModel && null != pa_tQuickSaveSlots)
   {
    if (0 < (lc_iLength = pa_tQuickSaveSlots.length))
    {
     lc_tListModel.removeAllElements();
   
     for (lc_iI = 0; lc_iI < lc_iLength; lc_iI++)
     {
      lc_tListModel.addElement(pa_tQuickSaveSlots[lc_iI]); 
      
      if (null != pa_tQuickSaveSlots[lc_iI] && null != pa_sSlot)
      {
       if (pa_tQuickSaveSlots[lc_iI].equals(pa_sSlot)) 
       {
        lc_iIndex = lc_iI; 
       }
      }
     }
     if (0 < lc_tListModel.getSize())
     {
      jListSlots.setSelectedIndex(-1 != lc_iIndex ? lc_iIndex : 0);
     }
    }
   }
  }
 
  
  
  /**
   * Returns the list size
   * 
   * @return  0 in case of empty list, otherwise amount of members
   */
  public final int getListSize()
  {
   GridLifeListModel    lc_tListModel = (GridLifeListModel) jListSlots.getModel();
   return (null != lc_tListModel ? lc_tListModel.size() : 0);    
  }
  
  
  
  /**
   * Returns the currently selected shape
   * 
   * @return  null in case of empty palette or error, shape otherwise
   */
  public final String getSelectedSlot()
  {
   Object lc_tObject = null;
   String lc_sSlot   = null;
   
   if (null != (lc_tObject =  jListSlots.getSelectedValue()))
   {
    if (lc_tObject instanceof String)
    {
     if (null != (lc_sSlot = (String) lc_tObject))
     {
      return lc_sSlot; 
     }
    }
   }
   return null;
  }
  
  
  
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jScrollPaneSlots = new javax.swing.JScrollPane();
        jListSlots = new javax.swing.JList();
        jButtonClose = new javax.swing.JButton();

        setDefaultCloseOperation(javax.swing.WindowConstants.DO_NOTHING_ON_CLOSE);
        java.util.ResourceBundle bundle = java.util.ResourceBundle.getBundle("gridlife/ui/resources/GridLifeQuickSlotDialog"); // NOI18N
        setTitle(bundle.getString("form.title")); // NOI18N
        setAlwaysOnTop(true);
        setModal(true);
        setName("Form"); // NOI18N

        jScrollPaneSlots.setName("jScrollPaneSlots"); // NOI18N

        jListSlots.setSelectionMode(javax.swing.ListSelectionModel.SINGLE_SELECTION);
        jListSlots.setName("jListSlots"); // NOI18N
        jScrollPaneSlots.setViewportView(jListSlots);

        jButtonClose.setText(bundle.getString("jButtonClose.text")); // NOI18N
        jButtonClose.setName("jButtonClose"); // NOI18N
        jButtonClose.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedButton_SL_Close(evt);
            }
        });

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jScrollPaneSlots, javax.swing.GroupLayout.DEFAULT_SIZE, 288, Short.MAX_VALUE)
                    .addComponent(jButtonClose, javax.swing.GroupLayout.Alignment.TRAILING))
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jScrollPaneSlots, javax.swing.GroupLayout.DEFAULT_SIZE, 248, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jButtonClose)
                .addGap(12, 12, 12))
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

  private void actionPerformedButton_SL_Close(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedButton_SL_Close
  if (null != m_tGuiConnector) m_tGuiConnector.handleButton_QS_Close();    
  }//GEN-LAST:event_actionPerformedButton_SL_Close

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton jButtonClose;
    private javax.swing.JList jListSlots;
    private javax.swing.JScrollPane jScrollPaneSlots;
    // End of variables declaration//GEN-END:variables
}
