/*
 * Game of Life
 * 
 */
package gridlife.ui;



/**
 * Imports
 * 
 */
import gridlife.core.GridLifeConstants;
import gridlife.shape.GridLifeShape;
import java.awt.Component            ;

import javax.swing.JList             ;
import javax.swing.JLabel            ;
import javax.swing.border.Border     ;
import javax.swing.border.EmptyBorder;
import javax.swing.ListCellRenderer  ;
import javax.swing.SwingConstants    ;



/**
 * Custom cell renderer for palette list. The DefaultListCellRenderer class will take care of
 * the JLabels text property, it's foreground and background colors, and so on.
 * 
 * @author Ulf Wagemann
 */
public class GridLifeShapePaletteListCellRenderer extends    JLabel
                                                  implements ListCellRenderer 
{
 protected static  Border      m_tNoFocusBorder;
 protected static  Border      m_tFocusBorder  ;
 
 
 public GridLifeShapePaletteListCellRenderer()
 { 
  super();
  
  m_tNoFocusBorder = new EmptyBorder(GridLifeConstants.GOL_SHAPE_RENDERER_INSETS, GridLifeConstants.GOL_SHAPE_RENDERER_INSETS, GridLifeConstants.GOL_SHAPE_RENDERER_INSETS, GridLifeConstants.GOL_SHAPE_RENDERER_INSETS);
  m_tFocusBorder   = new EmptyBorder(GridLifeConstants.GOL_SHAPE_RENDERER_INSETS, GridLifeConstants.GOL_SHAPE_RENDERER_INSETS, GridLifeConstants.GOL_SHAPE_RENDERER_INSETS, GridLifeConstants.GOL_SHAPE_RENDERER_INSETS);
  setOpaque(true);
  setBorder(m_tNoFocusBorder);  
 }
 
 
 
 /**
  * Component.getListCellRendererComponent()
  * 
  * @param pa_tList
  * @param pa_tValue
  * @param pa_iIndex
  * @param pa_bIsSelected
  * @param pa_bCellHasFocus
  * @return 
  */
 @Override
 public Component getListCellRendererComponent(JList   pa_tList        ,
                                               Object  pa_tValue       ,
                                               int     pa_iIndex       ,
                                               boolean pa_bIsSelected  ,
                                               boolean pa_bCellHasFocus) 
 {
  GridLifeShape lc_tShape = null;

  if (null != pa_tList)
  {
   setBackground(true == pa_bIsSelected ? pa_tList.getSelectionBackground() : pa_tList.getBackground());
   setForeground(true == pa_bIsSelected ? pa_tList.getSelectionForeground() : pa_tList.getForeground());
   setFont(pa_tList.getFont());
   
   setBorder(true == pa_bCellHasFocus ? m_tFocusBorder : m_tNoFocusBorder);
   setHorizontalTextPosition(SwingConstants.CENTER);
   setVerticalTextPosition  (SwingConstants.BOTTOM);
   setHorizontalAlignment   (SwingConstants.CENTER);
   setVerticalAlignment     (SwingConstants.CENTER);
   setIconTextGap(GridLifeConstants.GOL_SHAPE_RENDERER_GAP);
   
   if (pa_tValue instanceof GridLifeShape)
   { 
    if (null != (lc_tShape = (GridLifeShape) pa_tValue))
    {
     setText(lc_tShape.getShapeName());
     setIcon(lc_tShape.getShapeImageIcon());
    }
   }
   else
   {
    setText(pa_tValue.toString());
   }
  }
  return this;
 }

} // eoc
