/**
 * Game of Life
 * 
 */
package gridlife.ui;



/**
 * Imports
 * 
 */
import gridlife.shape.GridLifeShape          ;
import gridlife.shape.GridLifeShapeSetManager;

import java.awt.Color;



/**
 * Window for the shape palette editor
 * 
 * @author Ulf Wagemann
 */
public class GridLifeShapePaletteWindow extends javax.swing.JInternalFrame 
{
 private GridLifeGuiConnector m_tGuiConnector;
  
  
  /**
   * Constructor
   * 
   * @param pa_tGuiConnector    GuiConnector object
   */
  public GridLifeShapePaletteWindow(GridLifeGuiConnector pa_tGuiConnector) 
  {
   m_tGuiConnector = pa_tGuiConnector;
   initComponents();
   
   jListShapes.setCellRenderer(new GridLifeShapePaletteListCellRenderer()); 
   jListShapes.setModel(new GridLifeListModel());
   jListShapes.setBackground(java.awt.Color.white);
  }

  
  
  /**
   * Updates the combobox with those shapesets which contain valid shapes
   * 
   * @param pa_tShapeSetManager   ShapeSetManager to use
   */
  public final void updatePalettes(GridLifeShapeSetManager pa_tShapeSetManager, String pa_sSelection)
  {
   String[] lc_tNames   = null;
   String   lc_sSetName = null;
   
   int lc_iCount = 0;
   int lc_iI     = 0;
   int lc_iSets  = 0;
   int lc_iActiveIndex = 0;

   if (null != pa_tShapeSetManager && 0 < pa_tShapeSetManager.getShapeSetAmount())
   {
    if (null != (lc_tNames = pa_tShapeSetManager.getShapeSetNames()))
    {
     if (0 < (lc_iSets = lc_tNames.length))
     {
      for (lc_iI = 0; lc_iI < lc_iSets; lc_iI++)
      {
       if (null != (lc_sSetName  = lc_tNames[lc_iI])) 
       {
        jComboBoxPaletteSet.addItem(lc_sSetName);
        
        if (null != pa_sSelection)
        {
         if (pa_sSelection.equals(lc_sSetName))
         {
          lc_iActiveIndex = lc_iCount; 
         }
        }
        lc_iCount++;
       }
      }
     }
    }
   }
   if (0 < lc_iCount)
   {
    jComboBoxPaletteSet.setSelectedIndex(lc_iActiveIndex);
   }
  }
    
  
  
  /**
   * Returns the name of the selected palette
   * 
   * @return   Palette name
   */
  public final String getSelectedPaletteName()
  {
   if (-1 != jComboBoxPaletteSet.getSelectedIndex())
   {
    return (String) jComboBoxPaletteSet.getSelectedItem();  
   }
   return null;
  }
  
  
  /**
   * Returns the name of the selected palette
   * 
   * @return   Palette name
   */
  public final boolean hasPaletteSelection()
  {
   return (jListShapes.getSelectedIndex() != -1);
  }
  
  
  
  /**
   * Sets the list rendere and initializes the list with data
   * 
   * @param pa_tData   List data
   */
  public final void initList(GridLifeShape[] pa_tData, String pa_sSelection)
  {
   GridLifeShapePaletteListCellRenderer lc_tRenderer = new GridLifeShapePaletteListCellRenderer();
   jListShapes.setCellRenderer(lc_tRenderer); 
   jListShapes.setBackground(Color.white);
   
   int     lc_iLen = 0;
   int     lc_iPos = 0;
   boolean lc_bFound = false;

   if (null != pa_tData)
   {
    jListShapes.setListData(pa_tData);   
    if (pa_tData.length > 0)
    {
     if (null == pa_sSelection)
     {
      jListShapes.setSelectedIndex(0);
     }
     else
     {
      if (0 < (lc_iLen = pa_tData.length))
      {
       while (false == lc_bFound && lc_iPos < lc_iLen)
       {
        if (false == (lc_bFound = pa_tData[lc_iPos].getShapeName().equals(pa_sSelection)))
        {
         lc_iPos++; 
        }
       } // while 

       jListShapes.setSelectedIndex(false == lc_bFound ? 0 : lc_iPos);
      }    
     }
    }
   }
  }
  
  
  
  
  /**
   * Returns the currently selected shape
   * 
   * @return  null in case of empty palette or error, shape otherwise
   */
  public final GridLifeShape getSelectedShape()
  {
   Object        lc_tObject = null;
   GridLifeShape lc_tShape  = null;
   
   if (null != (lc_tObject =  jListShapes.getSelectedValue()))
   {
    if (lc_tObject instanceof GridLifeShape)
    {
     if (null != (lc_tShape = (GridLifeShape) lc_tObject))
     {
      return lc_tShape; 
     }
    }
   }
   return null;
  }  

  
  
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jScrollPaneShapeList = new javax.swing.JScrollPane();
        jListShapes = new javax.swing.JList();
        jComboBoxPaletteSet = new javax.swing.JComboBox();

        setClosable(true);
        setDefaultCloseOperation(javax.swing.WindowConstants.DO_NOTHING_ON_CLOSE);
        setIconifiable(true);
        setResizable(true);
        java.util.ResourceBundle bundle = java.util.ResourceBundle.getBundle("gridlife/ui/resources/GridLifeShapePaletteWindow"); // NOI18N
        setTitle(bundle.getString("Form.title")); // NOI18N
        setDoubleBuffered(true);
        setName("Form"); // NOI18N

        jScrollPaneShapeList.setHorizontalScrollBarPolicy(javax.swing.ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
        jScrollPaneShapeList.setName("jScrollPaneShapeList"); // NOI18N

        jListShapes.setSelectionMode(javax.swing.ListSelectionModel.SINGLE_SELECTION);
        jListShapes.setName("jListShapes"); // NOI18N
        jListShapes.addListSelectionListener(new javax.swing.event.ListSelectionListener() {
            public void valueChanged(javax.swing.event.ListSelectionEvent evt) {
                valueChangedList_SP_Shapes(evt);
            }
        });
        jScrollPaneShapeList.setViewportView(jListShapes);

        jComboBoxPaletteSet.setName("jComboBoxPaletteSet"); // NOI18N
        jComboBoxPaletteSet.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                actionPerformedCombobox_SP_Palette(evt);
            }
        });

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jScrollPaneShapeList, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 151, Short.MAX_VALUE)
                    .addComponent(jComboBoxPaletteSet, javax.swing.GroupLayout.Alignment.TRAILING, 0, 151, Short.MAX_VALUE))
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jComboBoxPaletteSet, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(jScrollPaneShapeList, javax.swing.GroupLayout.DEFAULT_SIZE, 616, Short.MAX_VALUE)
                .addContainerGap())
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

  
/********************************************* event handling methods ****************************************************/      
  private void actionPerformedCombobox_SP_Palette(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_actionPerformedCombobox_SP_Palette
    if (null != m_tGuiConnector) m_tGuiConnector.handleCombobox_SP_Palette(evt);    
  }//GEN-LAST:event_actionPerformedCombobox_SP_Palette

  private void valueChangedList_SP_Shapes(javax.swing.event.ListSelectionEvent evt) {//GEN-FIRST:event_valueChangedList_SP_Shapes
    if (null != m_tGuiConnector) m_tGuiConnector.handleList_SP_Palette(evt);    
  }//GEN-LAST:event_valueChangedList_SP_Shapes

  

 /***************************************** getters for UI objects *****************************************************/
 public javax.swing.JComboBox getComboboxPaletteSet() {return jComboBoxPaletteSet;}
 
 
 
  
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JComboBox jComboBoxPaletteSet;
    private javax.swing.JList jListShapes;
    private javax.swing.JScrollPane jScrollPaneShapeList;
    // End of variables declaration//GEN-END:variables
}
