/*
 * Game of Life
 * 
 */
package gridlife.ui;


/**
 * Imports
 * 
 */
import gridlife.core.GridLifeConstants;
import gridlife.core.GridLifeProperties;
import gridlife.core.GridLifeStatisticsManager;
import gridlife.core.GridLifeStatisticsRecord;

import java.awt.Font          ;
import java.awt.FontMetrics   ;
import java.awt.Color         ;
import java.awt.Rectangle     ;
import java.awt.Graphics2D    ;
import javax.swing.JScrollPane;



/**
 * This panel serves as a paint panel for statistics records.
 * 
 * @author Ulf Wagemann
 */
public class GridLifeStatisticsPaintPanel extends GridLifePaintPanel
{
 protected int m_iDrawMinX;
 protected int m_iDrawMaxX;
 
 protected GridLifeStatisticsManager m_tStatisticsManager;
 
 
 
 /**
  * Constructor 
  * 
  * @param pa_tScrollPane    scrollpane
  * @param pa_tRuleset       current properties
  */
 public GridLifeStatisticsPaintPanel(JScrollPane pa_tScrollPane, GridLifeProperties pa_tProperties, GridLifeStatisticsManager pa_tStatisticsManager)
 {
  super(pa_tScrollPane, pa_tProperties);

  m_iDrawMinX = 0;
  m_iDrawMaxX = 0;
  
  m_tStatisticsManager = pa_tStatisticsManager;
 }
  

 

 /**
  * Does the custom painting on the given graphics object.
  * 
  * @param pa_tGraphics  Paint on it!
  */
 public void paintCustom(Graphics2D pa_tGraphics)
 {
  Rectangle  lc_tRect       = null;
  
  //
  // get visible rect for later comparisions
  //
  if (null != m_tScrollPane)
  {
   if (null != m_tScrollPane.getViewport())
   {
    lc_tRect = m_tScrollPane.getViewport().getViewRect();
   }
  }

  pa_tGraphics.setColor(m_tColorBackground);
  pa_tGraphics.setPaintMode();
  pa_tGraphics.setStroke(m_tLineStrokeSolid);
  pa_tGraphics.fillRect(0, 0, lc_tRect.width, lc_tRect.height);
  
  //
  // only continue with valid objects
  //
  if (null != pa_tGraphics && null != lc_tRect)
  {
   drawGrid(pa_tGraphics, lc_tRect);   
  } 
 }
  


 /**
  * Draws the grid
  * 
  * @param pa_tGraphics2D    Graphics object to draw on
  * @param pa_tRect          Visible rectangle
  */
 private void drawGrid(Graphics2D pa_tGraphics2D, Rectangle pa_tRect)
 {
  int lc_iMaxCells  =  0;  
  int lc_iDrawX     =  0;
  int lc_iDrawY     =  0;
  int lc_iPrevDrawX = -1;
  int lc_iPrevDrawY = -1;
  
  int lc_iMaxHeight         = 0;
  int lc_iHalfMaxHeight     = 0;
  int lc_iQuarterMaxHeight  = 0;
  int lc_iPercentCellAmount = 0;
  int lc_iZeroLine          = 0;
  int lc_iHalfFontHeight    = 0;
  
  FontMetrics lc_tFontMetrics = null;
  GridLifeStatisticsRecord lc_tStatisticsRecord = null;
  
  if (null != pa_tGraphics2D && null != pa_tRect && null != m_tStatisticsManager && null != m_tProperties)
  {
   lc_iMaxCells = m_tProperties.getColumns() * m_tProperties.getRows();
   
   lc_iMaxHeight        = pa_tRect.height - (2 * GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP);
   lc_iHalfMaxHeight    = lc_iMaxHeight / 2  ;
   lc_iQuarterMaxHeight = lc_iMaxHeight / 4  ;
   lc_iZeroLine         = GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iMaxHeight;
   lc_iHalfFontHeight   = (GridLifeConstants.GOL_STAT_WINDOW_FONT_HEIGHT) / 2;
   
   pa_tGraphics2D.setFont(new Font(Font.SANS_SERIF, Font.PLAIN, GridLifeConstants.GOL_STAT_WINDOW_FONT_HEIGHT)); 
   lc_tFontMetrics = pa_tGraphics2D.getFontMetrics();

   pa_tGraphics2D.setPaintMode();
   pa_tGraphics2D.setStroke(m_tLineStrokeDotted);
   pa_tGraphics2D.setRenderingHints(m_tRenderingHints);
   
   //
   // paint 100% line and text below
   //
   pa_tGraphics2D.setColor(m_tStatisticsLineColor);
   pa_tGraphics2D.drawLine(0, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP, pa_tRect.width, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP);
   pa_tGraphics2D.setColor(m_tShadowColor);
   pa_tGraphics2D.drawString("100%", 3, 1 + GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iHalfFontHeight);
   pa_tGraphics2D.setColor(Color.black);
   pa_tGraphics2D.drawString("100%", 2, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iHalfFontHeight);
  
   //
   // paint 75% line 
   //
   pa_tGraphics2D.setColor(m_tStatisticsLineColor);
   pa_tGraphics2D.drawLine(0, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iQuarterMaxHeight, pa_tRect.width, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iQuarterMaxHeight);

   //
   // paint 50% line
   //
   pa_tGraphics2D.setColor(m_tStatisticsLineColor);
   pa_tGraphics2D.drawLine(0, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iHalfMaxHeight, pa_tRect.width, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iHalfMaxHeight);
   pa_tGraphics2D.setColor(m_tShadowColor);
   pa_tGraphics2D.drawString("50%", 3, 1 + lc_iHalfMaxHeight + GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iHalfFontHeight);
   pa_tGraphics2D.setColor(Color.black);
   pa_tGraphics2D.drawString("50%", 2, lc_iHalfMaxHeight + GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iHalfFontHeight);

   //
   // paint 25% line 
   //
   pa_tGraphics2D.setColor(m_tStatisticsLineColor);
   pa_tGraphics2D.drawLine(0, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iHalfMaxHeight + lc_iQuarterMaxHeight, pa_tRect.width, GridLifeConstants.GOL_STAT_WINDOW_DRAWING_GAP + lc_iHalfMaxHeight + lc_iQuarterMaxHeight);

   //
   // paint 0% line
   //
   pa_tGraphics2D.setColor(m_tStatisticsLineColor);
   pa_tGraphics2D.drawLine(0, lc_iZeroLine, pa_tRect.width, lc_iZeroLine);
   pa_tGraphics2D.setColor(m_tShadowColor);
   pa_tGraphics2D.drawString("0%", 3, 1 + lc_iZeroLine  + lc_iHalfFontHeight);  
   pa_tGraphics2D.setColor(Color.black);
   pa_tGraphics2D.drawString("0%", 2, lc_iZeroLine  + lc_iHalfFontHeight);  
  
   
   //
   // paint records
   //
   pa_tGraphics2D.setStroke(m_tLineStrokeSolid);
   pa_tGraphics2D.setColor(Color.red);    
   
   if (null != lc_tFontMetrics)
   {
    m_iDrawMinX = 2 + lc_tFontMetrics.stringWidth("100%") + 10;
    m_iDrawMaxX = pa_tRect.width;
    lc_iDrawX   = m_iDrawMaxX   ;
    
    if (true == m_tStatisticsManager.startReading())
    {
     while (true == m_tStatisticsManager.hasReadNext() && lc_iDrawX > m_iDrawMinX)
     {
      if (null != (lc_tStatisticsRecord = m_tStatisticsManager.readNext())) 
      {
       //
       // get cell amount, compute y location
       //
       lc_iPercentCellAmount = (lc_tStatisticsRecord.getCellAmount() * lc_iMaxHeight) / lc_iMaxCells;
       lc_iDrawY = lc_iZeroLine - lc_iPercentCellAmount; 

        
       if (-1 == lc_iPrevDrawX || -1 == lc_iPrevDrawY) 
       {
        //
        // set point
        //
        pa_tGraphics2D.drawLine(lc_iDrawX, lc_iDrawY, lc_iDrawX, lc_iDrawY); 
       }
       else
       {
        //
        // draw line to previous location
        //
        pa_tGraphics2D.drawLine(lc_iPrevDrawX, lc_iPrevDrawY, lc_iDrawX, lc_iDrawY);  
       }
      
       //
       // store point for next drawing
       //
       lc_iPrevDrawX = lc_iDrawX;
       lc_iPrevDrawY = lc_iDrawY;
      }
      lc_iDrawX--;
     } // while
    }
    
   }
  }
 }
 
} // eoc
